;; This is example boot code for the absolute example.

;; this code is stored at page 0, offset 0, and will be executed when the 
;; cart is started
org &0000
jp start

;; RED,BLUE,0,GREEN
palette:
  defw &0F08 ; BLUE
  defw &FF0F ; WHITE
  defw &0000 ; BLACK
  defw &8000 ; BROWN  
  defw &F000 ; RED
  defw &0F00 ; BLUE
  defw &F00F;A ; YELLOW 
  defw &F008;A;6 ; ORANGE
  defw &5403 ; PURPLE
  defw &8F0A;9 ; LIGHT BLUE
  defw &5C05 ; MED BLUE
  defw &370F;A ; LIGHT GREEN
  defw &350A;6 ; SEA GREEN
  defw &3905 ; TEAL
  defw &0805 ; MAUVE
  defw &0005 ; DARK GREEN
  defw &0C05 ; BORDER


;palette
;  defw &0000 ; TRANS
;  defw &FF0F ; WHITE
;  defw &0000 ; BLACK
;  defw &8000 ; BROWN  
;  defw &F000 ; RED
;  defw &0F00 ; BLUE
;  defw &F00F ; YELLOW 
;  defw &F008 ; ORANGE
;  defw &8F00 ; PURPLE
;  defw &0F0F ; LIGHT BLUE
;  defw &0F08 ; MED BLUE
;  defw &000F ; LIGHT GREEN
;  defw &800F ; SEA GREEN
;  defw &0808 ; TEAL
;  defw &8F08 ; MAUVE
;  defw &0008 ; DARK GREEN
;  defw &0C05 ; BORDER

crtc_data: defb &3f,&28,&2e,&8e,&26,&00,&19,&1e,&00,&07,&00,&00,&30,&00,&c0,&00
end_crtc_data:

;; sequence to unlock asic
sequence: defb &ff,&00,&ff,&77,&b3,&51,&a8,&d4,&62,&39,&9c,&46,&2b,&15,&8a,&cd,&ee

boot_game:
  ;; OO-IULMM
  ;; disable upper and lower rom
  ld bc,&7f00+%10001100
  out (c),c

  ld hl,&0e00
  jp (hl)			;; and execute game
end_boot_game:

start:
di					;; disable interrupts
im 1					;; set interrupt mode 1
ld bc,&f782			;; setup initial PPI port directions
out (c),c
ld bc,&f400			;; set initial PPI port A (AY)
out (c),c
ld bc,&f600			;; set initial PPI port C (AY direction)
out (c),c

ld bc,&7fc0			;; set initial RAM configuration
out (c),c

;; unlock ASIC so we can access ASIC registers
ld b,&bc
ld hl,sequence
ld e,17
seq:
ld a,(hl)
out (c),a
inc hl
dec e
jr nz,seq

;; set initial CRTC settings (screen dimensions etc)
ld hl,end_crtc_data
ld bc,&bc0f
crtc_loop:
out (c),c
dec hl
ld a,(hl)
inc b
out (c),a
dec b
dec c
jp p,crtc_loop


  ; MOVE SCREEN MEMORY TO 8000-BFFF
  ld hl,0        ;; get scroll offset
  ld a,h
  or &20                    ;; This defines the "base" of the screen in 16k units.
                            ;; &00 -> screen uses &0000-&3fff
                            ;; &10 -> screen uses &4000-&7fff
                            ;; &20 -> screen uses &8000-&bfff
                            ;; &30 -> screen uses &c000-&ffff
  ld h,a
  ld bc,&bc0c                ;; select CRTC register 12
  out (c),c
  inc b                    ;; B = &BD
  out (c),h                ;; write to CRTC register 12
  dec b
  inc c                    ;; BC = &BC0D
  out (c),c                ;; select CRTC register 13
  inc b
  out (c),l                ;; write to CRTC register 13 

;; select page screen is in.
ld bc,&df81
out (c),c
ld hl,&c000		;; copy from ROM
ld de,&8000		;; to RAM &8000
ld bc,&4000
ldir

; SET STACK POINTER
ld sp,&8000
; SET INTERRUPT FUNCTION?
ld a,&c9 ;(RET)
ld hl,&0038
ld (hl),a

xor a
ld b,16
ld hl,palette
setpaletteloop:
  push hl

  push af
  ld a,(hl)
  inc hl
  ld l,(hl)
  ld h,a
  pop af

  push af
  push bc

  ; SET PALETTE

  ld bc,&7fb8 ; PAGE IN PLUS REGISTERS
  out (c),c   ; ASIC RAMBANK AT 4000-7FFF
  ex de,hl    ; SWAP PALETTE TO DE
  ld hl,&6400 ; START OF CPC PLUS PALETTE
  add a,a     ; DOUBLE PALETTE NUMBER
  ld l,a
  ld (hl),e   ; WRITE PALETTE DATA TO REGISTERS
  inc hl
  ld (hl),d
  ex de,hl
  ld bc,&7fa0 ; PAGE OUT PLUS REGISTERS
  out (c),c

  pop bc
  pop af

  pop hl

  inc a
  inc hl
  inc hl
djnz setpaletteloop

;; COPY BANKS OF CODE TO RAM
ld bc,&df82
out (c),c
ld hl,&ce00		;; copy from ROM
ld de,&0e00		;; to RAM under ROM
ld bc,&3200
ldir

;; COPY BANKS OF CODE TO RAM
ld bc,&df83
out (c),c
ld hl,&c000		;; copy from ROM
ld de,&4000		;; to RAM under ROM
ld bc,&4000
ldir

;; COPY BOOT CODE TO RAM
;; BOOT CODE MUST NOT BE IN UPPER OR LOWER ROM AREAS
;; ALSO MUST NOT BE OVERWRITTEN BY ABOVE GAME CODE
ld bc,&df80
out (c),c
ld hl,boot_game
ld de,&7f00
ld bc,end_boot_game-boot_game
ldir

;; JUMP TO BOOT FUNCTION
ld bc,&df80 ; SET MEMORY BACK TO STANDARD
out (c),c
jp &7f00

;end start
