ifdef iscart
  screenadr           equ &8000
endif
ifndef iscart
  screenadr           equ &c000
endif
topstatusbarline    equ screenadr+&3E54
secondstatusbarline equ screenadr+&2EA4
screensize          equ &4000
linewidth           equ 2048

; DE = PTR TO TEXT
; HL = SCREEN ADDRESS
; A PRESERVED
gra_wr_string2:
  push af
  ld a,(de)
  cp " " ; SKIP LEADING SPACE
  jr nz,printtextloop
  inc de
  printtextloop:
    ld a,(de)
    cp 255 ; COMPARE TO 255 AS 0 WILL BE A SPRITE NUMBER
    jr z,popaf
    ; SCREEN TEXT BUFFER CAN BE WIPED BY GAME MAP CLEARANCE
    ; IF SO, IT WILL BE 0 - SO SKIP WRITING TO SCREEN
    ;or a  
    ;jr z,popaf
    
    push hl ; BACK UP CURRENT GFX POS
    push de ; BACK UP DE TO READ PTR TABLE
    ld de,letters_ptr_table
    sub " " ; CONVERT LETTER TO TILE INDEX NUMBER
    call get_tile_ptr
    call font_draw
    pop de
    pop hl ; RESTORE CURRENT GFX POS
    inc hl ; ADVANCE ONE CHAR SIZE
    inc hl
    inc de
  jr printtextloop

popaf:
  pop af
ret

ifndef isplus
; SET PALETTE TO LAND OR SEA
; INPUT
; HL = PALETTE TABLE TO USE
dopens:
  ld b,16    ;; 4 pens for mode 1
  xor a      ;; initial pen index
  set_pensa:
  push bc
  push af
  ld c,(hl)  ;; B,C = inks for pen. If they are the same then no flashing
  ld b,c
  inc hl
  push hl
  call scr_set_ink
  pop hl
  pop af
  pop bc
  inc a     ;; increment pen index
  djnz set_pensa
ret
endif

; ------------------------------------------------
; PLUS PALETTE FUNCTIONS

ifdef isplus

; THESE BYTES STORE AMOUNT OF EACH NYBBLE IS TO BE ADJUSTED BY FROM IN SUNSET/SUNRISE TABLE
adjustnybblestable:
  defb 0:decgreen  ; DEC GREEN
  defb 0:decempty  ; EMPTY
  defb 0:decblue   ; DEC BLUE
  defb 0:decred    ; DEC RED

; DECREMENT NYBBLES BY AMOUNT IN ABOVE TABLE
; DE = INK IN NYBBLES

; OUTPUTS
; DE  = ADJUSTED NIBBLES

; LOAD ADJUSTING NYBBLES FROM ABOVE TABLE
decnybbles:
  ld a,(decgreen-1)
  ld (decgreennybble-1),a
  ld a,(decred-1)
  ld (decrednybble-1),a
  ld a,(decblue-1)
  ld (decbluenybble-1),a
decnybbles2:
   push hl
   ld a,d
   and %11110000
   rrca                     ; GET LEFT NIBBLE OF D
   rrca
   rrca
   rrca
   sub 0:decgreennybble;decemptynybble

   jr c,setazeroandreturn
   returnafterzero:

   rlca
   rlca
   rlca
   rlca
   ld h,a                   ; STORE RESULT IN H
   ;ld h,0                   ; STORE RESULT IN H

   ld a,d
   and %00001111            ; GET RIGHT NIBBLE OF D
   sub 0:decrednybble     ; DECREMENT

   jr c,setazeroandreturn2
   returnafterzero2:

   or h                     ; COMBINE RESULTS
   ld d,a                   ; STORE RESULT IN D

   ; REPEAT FOR E/L
   ;ld a,e
   ;and %11110000            ; GET LEFT NIBBLE OF E
   ;rrca                     ; ROTATE TO RIGHT
   ;rrca
   ;rrca
   ;rrca
   ;sub 0sdecrednybble       ; DECREMENT

   ;jr c,setazeroandreturn3
   ;returnafterzero3

   ;rlca
   ;rlca
   ;rlca
   ;rlca
   ;ld h,a                   ; STORE RESULT IN H
   ;ld h,0

   ld a,e
   and %00001111            ; GET RIGHT NIBBLE OF E
   sub 0:decbluenybble      ; DECREMENT

   jr c,setazeroandreturn4
   returnafterzero4:

   ;or h                     ; COMBINE RESULTS
   ld e,a                   ; STORE RESULT IN E
   pop hl
ret

setazeroandreturn:
  xor a
  jr returnafterzero
setazeroandreturn2:
  xor a
  jr returnafterzero2
setazeroandreturn4:
  xor a
  jr returnafterzero4

setsunrisenybbles:
  ld a,(changedpenid-1)
  ld hl,sunrisetable
  jr docopynybbles
setsunsetnybbles:
  ; DIM INK BY DARKNESS OFFSET
  ld a,(changedpenid-1)
  ld hl,sunsettable
  docopynybbles:
  rlca ; DOUBLE DOUBLE A
  rlca
  ; COPY 4 BYTES TO ADJUSTMENT TABLE
  ld b,0
  ld c,a
  add hl,bc
  ld de,adjustnybblestable
  ld bc,4
  ldir
ret

endif

; SET SCREEN INK FOR PLUS
; INPUTS
; DE = PALETTE COLOUR
; A  = PEN TO CHANGE
scr_set_ink_plus:
  push af
  call decnybbles
  pop af

  push hl
  ld bc,&7fb8 ; PAGE IN PLUS REGISTERS
  out (c),c   ; ASIC RAMBANK AT 4000-7FF
  ld h,&64    ; &6400 - START OF CPC PLUS PALETTE
  add a,a     ; DOUBLE PALETTE NUMBER
  ld l,a
  ld (hl),d   ; WRITE PALETTE DATA TO REGISTERS
  inc hl
  ld (hl),e
  ld bc,&7fa0 ; PAGE OUT PLUS REGISTERS
  out (c),c
  pop hl
ret

; INPUT
; HL = PALETE TO USE
dopens:
  xor a;ld a,0
  ld b,16
  push hl
  setpaletteloop:
    ld d,(hl)
    inc hl
    ld e,(hl)
    inc hl

    push af
    push bc
    call scr_set_ink_plus
    pop bc
    pop af

    inc a
  djnz setpaletteloop
  pop hl
ret


; SET PALETTE
; INPUTS
; A = PEN
; HL = &0BGR
;setpalettesss
;  ld bc,&7fb8 ; PAGE IN PLUS REGISTERS
;  out (c),c   ; ASIC RAMBANK AT 4000-7FFF
;  ex de,hl    ; SWAP PALETTE TO DE
;  ld hl,&6400 ; START OF CPC PLUS PALETTE
;  add a,a     ; DOUBLE PALETTE NUMBER
;  ld l,a
;  ld (hl),e   ; WRITE PALETTE DATA TO REGISTERS
;  inc hl
;  ld (hl),d
;  ex de,hl
;  ld bc,&7fa0 ; PAGE OUT PLUS REGISTERS
;  out (c),c
;ret

endif


checkdopenssealands:
  ld a,(nighttime)
  bit 1,a                ; WE WANT SEA PALETE
  jr nz,wearesettosea
  bit 3,a                ; CHECK IF WE ARE USING PALETTE ALREADY
  ret z                  ; NO CHANGE NEEDED
  ; SET LAND PALETTE
  jr dopensland

  ; SET SEA PALETTE
  wearesettosea:
  bit 3,a                ; CHECK IF WE ARE USING PALETTE ALREADY
  ret nz                 ; NO CHANGE NEEDED

dopenssea:
  ; RECORD THAT WE MOVED TO SEA
  set 3,a
  ld (nighttime),a

  ; CHECK WHETHER TO USE DAY OR NIGHT PALETTE
  bit 0,a
  jr z,usedaypalette
  ld hl,penswater
  jp dopens

  usedaypalette:
  ld hl,penswater
  jp dopens

dopensland:
  ; RECORD THAT WE MOVED TO LAND
  res 3,a
  ld (nighttime),a

  ; CHECK WHETHER TO USE DAY OR NIGHT PALETTE
  bit 0,a
  jr nz,donightpalette
  ld hl,pens
  jp dopens

  donightpalette:
  ld hl,pens
  jp dopens

; INPUTS A = PEN
ClearScreen:
  ld hl,screenadr
  ; DRAW 160 HORIZONTAL LINES
  call drawhoriz32
  call drawhoriz64
  drawhoriz64:
  call drawhoriz32
  drawhoriz32:
  call drawhoriz16
  drawhoriz16:
  call drawhoriz8
  drawhoriz8:
  call drawhoriz4
  drawhoriz4:
  call DrawHorizLine
  call DrawHorizLine
  call DrawHorizLine
  jp DrawHorizLine

;scr_next_line_hl equ &bc26
; BELOW ROUTINE ONLY WORKS IF SCREEN MEMORY STARTS AT C000
scr_next_line_hl:
  ld a,h
  add &08
  ld h,a

ifdef iscart
  ; CHECK IF WE WENT PAST END OF SCREEN
  sub &c0   ; IF USING &8000 FOR SCREEN MEM
  ret c
endif
ifndef iscart
  bit 7,h   ; IF USING &C000 FOR SCREEN MEM
  ret nz
endif

  ld bc,&C050
  add hl,bc
ret

;scr_prev_line_hl:
;  ld a,h
;  sub &08
;  ld h,a
;  bit 7,h
;  ret nz
;  ld bc,&c050
;  sbc hl,bc
;ret

; INPUTS
; HL = TILE ID
ClearTileByTileID:
  call gettilepixelpos
  call get_scr_addr
  xor a ; SET BACKGROUND COLOUR
; INPUTS
; HL = SCREEN ADR
; A = COLOUR
ClearTile:
  push af
  push bc
  ld b,16
  ; SAVES US HAVING TO PUSH POP AF
  ld (selfmodpencol-1),a
  loopyloo3:
    ; COPY HL TO DE
    push bc
    push hl
    push hl
    pop de 
    ld (hl),1:selfmodpencol
    inc de
    ldi
    ldi
    ldi
    pop hl
    call scr_next_line_hl
    pop bc
  djnz loopyloo3
  pop bc
  pop af
ret