;; Midi2ay playback code for Amstrad CPC
;;
;; Uses firmware functions to allow music to play
;; while BASIC is active.
;;
;; CALL &8000 to setup interrupt and to play music
;; CALL &8003 to stop music
;; 
;;
;; Code assembles using wincpc's assembler.
;;
;; To use this:
;; 1. Use Midi2ay to convert a .mid file and output as asm.
;; 2. Delete the data after notas in this file.
;; 3. Copy and paste the notas from the new asm file to the end of this code
;; 4. Assemble and enjoy.
;;
;; NOTE: The tone data stored here is for the Spectrum which
;; has an AY sound chip running at 1.77Mhz.
;;
;; The CPC has an AY sound chip running at 1.0Mhz, so the tones will not 
;; be correct.

;;--------------------------------------------------------------------------------------------

kl_new_frame_fly equ &bcd7
mc_sound_register equ &bd34
kl_del_frame_fly equ &bcdd
;;--------------------------------------------------------------------------------------------

;org	&8000

;;--------------------------------------------------------------------------------------------

jp play_music		;; +0
jp stop_music		;; +3

;;--------------------------------------------------------------------------------------------

play_music:
xor a
ld (counter),a
ld (count_active),a

;; setup an interrupt to be executed every frame flyback 
;; (50hz)
ld hl,ff_event_block
ld b,&81
ld c,0
ld de,ff_event_routine
call kl_new_frame_fly
ret

;;--------------------------------------------------------------------------------------------

stop_music:
ld hl,ff_event_block
call kl_del_frame_fly
ret

;;--------------------------------------------------------------------------------------------

ff_event_block:
defs 10

;;--------------------------------------------------------------------------------------------

ff_event_routine:
;; counter is active?

ld a,(count_active)
or a
;; no, do next packet
jr z,packet_begin

;; yes it's active
;; count down
ld a,(counter)
dec a
ld (counter),a

;; if counter is not zero, we quit and continue
or a
ret nz

;; counter is not active any more
xor a
ld (count_active),a

;; we now continue from counter and read remaining data in packet
ld hl,(pos)
jr cont_from_counter

;;--------------------------------------------------------------------------------------------

;; read a complete packet 
packet_begin:
ld	hl,(pos)

;; continue with part of a packet
packet_cont:

;; counter?
ld	a,(hl)
or	a
jr	nz,counter_set

;; continue after doing a counter
cont_from_counter:
inc	hl
ld	a,(hl)
cp  &ff		;; end
jr	z,music_end
cp  &fe		;; skip?
jr	z,skip_
	
;; write to ay
ld a,(hl)
inc hl
ld c,(hl)
inc hl
call mc_sound_register
		
jr	packet_cont

;;--------------------------------------------------------------------------------------------
;; start the counter

counter_set:
ld	(pos),hl
ld (counter),a
ld (count_active),a

ret

;;--------------------------------------------------------------------------------------------
;; skip data

skip_:	
inc	hl
inc	hl
ld	(pos),hl
ret

;;--------------------------------------------------------------------------------------------
;; music end

music_end:
;; loop
ld hl,notas
ld (pos),hl
jr packet_cont

;;--------------------------------------------------------------------------------------------

count_active: defb 0
counter: defb 0
pos:	dw	notas

;;--------------------------------------------------------------------------------------------


;; data

notas:
notas

	db &00,&07,&38,&00,&08,&00,&00,&09,&00
	db &00,&10,&00,&00,&00,&50,&00,&01,&01
	db &00,&08,&08,&0f,&08,&00,&01,&00,&a8
	db &00,&01,&00,&00,&08,&08,&00,&02,&50
	db &00,&03,&01,&0e,&08,&00,&01,&00,&50
	db &00,&01,&01,&00,&08,&08,&00,&02,&a8
	db &00,&03,&00,&00,&04,&50,&00,&05,&01
	db &0e,&08,&00,&01,&00,&a8,&00,&01,&00
	db &00,&08,&08,&00,&02,&50,&00,&03,&01
	db &00,&04,&a8,&00,&05,&00,&0e,&08,&00
	db &01,&00,&50,&00,&01,&01,&00,&08,&08
	db &00,&02,&a8,&00,&03,&00,&00,&04,&50
	db &00,&05,&01,&0e,&08,&00,&01,&00,&a8
	db &00,&01,&00,&00,&08,&08,&00,&02,&50
	db &00,&03,&01,&00,&04,&a8,&00,&05,&00
	db &07,&08,&00,&00,&00,&50,&00,&01,&01
	db &00,&08,&08,&00,&02,&a8,&00,&03,&00
	db &00,&04,&50,&00,&05,&01,&07,&08,&00
	db &08,&08,&08,&00,&02,&50,&00,&03,&01
	db &00,&04,&a8,&00,&05,&00,&07,&08,&00
	db &00,&00,&a8,&00,&01,&00,&00,&08,&08
	db &00,&04,&50,&00,&05,&01,&0e,&08,&00
	db &01,&00,&50,&00,&01,&01,&00,&08,&08
	db &00,&02,&a8,&00,&03,&00,&0f,&08,&00
	db &01,&00,&a8,&00,&01,&00,&00,&08,&08
	db &00,&02,&50,&00,&03,&01,&00,&04,&a8
	db &00,&05,&00,&0e,&08,&00,&01,&00,&50
	db &00,&01,&01,&00,&08,&08,&00,&02,&a8
	db &00,&03,&00,&00,&04,&50,&00,&05,&01
	db &0e,&08,&00,&01,&00,&a8,&00,&01,&00
	db &00,&08,&08,&00,&02,&50,&00,&03,&01
	db &00,&04,&a8,&00,&05,&00,&0e,&08,&00
	db &01,&00,&50,&00,&01,&01,&00,&08,&08
	db &00,&02,&a8,&00,&03,&00,&00,&04,&50
	db &00,&05,&01,&0e,&08,&00,&01,&00,&a8
	db &00,&01,&00,&00,&08,&08,&00,&02,&50
	db &00,&03,&01,&00,&04,&a8,&00,&05,&00
	db &07,&08,&00,&00,&00,&50,&00,&01,&01
	db &00,&08,&08,&00,&02,&a8,&00,&03,&00
	db &00,&04,&50,&00,&05,&01,&07,&08,&00
	db &08,&08,&08,&00,&02,&50,&00,&03,&01
	db &00,&04,&a8,&00,&05,&00,&07,&08,&00
	db &00,&00,&a8,&00,&01,&00,&00,&08,&08
	db &00,&04,&50,&00,&05,&01,&0e,&08,&00
	db &01,&08,&08,&00,&09,&08,&00,&04,&a8
	db &00,&05,&00,&0f,&08,&00,&00,&09,&00
	db &01,&00,&85,&00,&08,&08,&00,&02,&a8
	db &00,&03,&00,&00,&09,&08,&0e,&08,&00
	db &00,&09,&00,&01,&00,&70,&00,&08,&08
	db &00,&02,&50,&00,&03,&01,&00,&09,&08
	db &00,&04,&85,&0e,&08,&00,&00,&09,&00
	db &01,&00,&64,&00,&08,&08,&00,&02,&a8
	db &00,&03,&00,&00,&09,&08,&00,&04,&70
	db &0e,&08,&00,&00,&09,&00,&01,&00,&5e
	db &00,&08,&08,&00,&02,&50,&00,&03,&01
	db &00,&09,&08,&00,&04,&64,&0e,&08,&00
	db &00,&09,&00,&01,&08,&08,&00,&02,&a8
	db &00,&03,&00,&00,&09,&08,&00,&04,&5e
	db &07,&08,&00,&00,&09,&00,&00,&00,&64
	db &00,&08,&08,&00,&02,&50,&00,&03,&01
	db &00,&09,&08,&07,&08,&00,&00,&09,&00
	db &08,&00,&70,&00,&08,&08,&00,&09,&08
	db &00,&04,&64,&07,&08,&00,&00,&09,&00
	db &00,&00,&7e,&00,&08,&08,&00,&02,&a8
	db &00,&03,&00,&00,&09,&08,&00,&04,&70
	db &0e,&08,&00,&00,&09,&00,&01,&08,&09
	db &00,&02,&96,&00,&09,&07,&00,&04,&50
	db &00,&05,&01,&00,&0a,&08,&0f,&04,&7e
	db &00,&05,&00,&00,&0a,&00,&01,&02,&a8
	db &00,&09,&08,&00,&04,&96,&00,&0a,&07
	db &07,&00,&a8,&00,&08,&08,&00,&02,&7e
	db &00,&09,&00,&00,&04,&a8,&00,&0a,&00
	db &00,&00,&85,&00,&08,&08,&00,&02,&a8
	db &00,&09,&07,&07,&02,&85,&00,&09,&00
	db &01,&02,&50,&00,&03,&01,&00,&09,&08
	db &00,&04,&85,&0e,&02,&85,&00,&03,&00
	db &00,&09,&00,&00,&04,&50,&00,&05,&01
	db &01,&08,&00,&00,&00,&a8,&00,&08,&08
	db &00,&04,&85,&00,&05,&00,&0e,&08,&00
	db &01,&00,&7e,&00,&08,&09,&00,&02,&96
	db &00,&09,&07,&00,&04,&50,&00,&05,&01
	db &00,&0a,&08,&0e,&04,&7e,&00,&05,&00
	db &00,&0a,&00,&01,&02,&a8,&00,&09,&08
	db &00,&04,&96,&00,&0a,&07,&07,&02,&96
	db &00,&09,&07,&00,&04,&7e,&00,&0a,&00
	db &00,&08,&00,&00,&09,&00,&00,&00,&85
	db &00,&08,&08,&00,&02,&a8,&00,&09,&07
	db &00,&04,&50,&00,&05,&01,&00,&0a,&08
	db &07,&04,&85,&00,&05,&00,&00,&0a,&00
	db &08,&04,&50,&00,&05,&01,&00,&0a,&08
	db &07,&04,&85,&00,&05,&00,&00,&0a,&00
	db &00,&08,&00,&00,&09,&00,&00,&00,&a8
	db &00,&08,&08,&00,&02,&85,&00,&04,&a8
	db &0e,&08,&00,&01,&08,&08,&00,&02,&50
	db &00,&03,&01,&00,&09,&08,&0f,&08,&00
	db &00,&09,&00,&01,&00,&85,&00,&08,&08
	db &00,&02,&a8,&00,&03,&00,&00,&09,&08
	db &0e,&08,&00,&00,&09,&00,&01,&00,&70
	db &00,&08,&08,&00,&02,&50,&00,&03,&01
	db &00,&09,&08,&00,&04,&85,&0e,&08,&00
	db &00,&09,&00,&01,&00,&64,&00,&08,&08
	db &00,&02,&a8,&00,&03,&00,&00,&09,&08
	db &00,&04,&70,&0e,&08,&00,&00,&09,&00
	db &01,&00,&5e,&00,&08,&08,&00,&02,&50
	db &00,&03,&01,&00,&09,&08,&00,&04,&64
	db &0e,&08,&00,&00,&09,&00,&01,&08,&08
	db &00,&02,&a8,&00,&03,&00,&00,&09,&08
	db &00,&04,&5e,&07,&08,&00,&00,&09,&00
	db &00,&00,&64,&00,&08,&08,&00,&02,&50
	db &00,&03,&01,&00,&09,&08,&07,&08,&00
	db &00,&09,&00,&08,&00,&70,&00,&08,&08
	db &00,&09,&08,&00,&04,&64,&07,&08,&00
	db &00,&09,&00,&00,&00,&7e,&00,&08,&08
	db &00,&02,&a8,&00,&03,&00,&00,&09,&08
	db &00,&04,&70,&0e,&08,&00,&00,&09,&00
	db &01,&00,&5e,&00,&08,&07,&00,&02,&fc
	db &00,&09,&08,&00,&04,&7e,&00,&0a,&06
	db &0f,&02,&7e,&00,&09,&06,&00,&04,&5e
	db &00,&0a,&00,&01,&02,&8d,&00,&09,&08
	db &00,&04,&7e,&00,&0a,&06,&06,&00,&8d
	db &00,&08,&08,&00,&02,&5e,&00,&09,&00
	db &00,&04,&8d,&00,&0a,&00,&01,&02,&64
	db &00,&09,&07,&00,&04,&7e,&00,&0a,&05
	db &07,&00,&64,&00,&08,&07,&00,&02,&7e
	db &00,&09,&05,&00,&04,&8d,&00,&0a,&00
	db &01,&02,&fc,&00,&09,&08,&00,&04,&7e
	db &00,&0a,&05,&0e,&00,&fc,&00,&08,&08
	db &00,&02,&7e,&00,&09,&05,&00,&04,&64
	db &00,&0a,&00,&00,&00,&7e,&00,&08,&05
	db &00,&02,&fc,&00,&09,&00,&00,&04,&7e
	db &01,&00,&8d,&00,&08,&08,&00,&02,&7e
	db &00,&09,&05,&01,&02,&8d,&00,&09,&00
	db &0d,&08,&00,&01,&00,&5e,&00,&08,&07
	db &00,&02,&fc,&00,&09,&08,&00,&0a,&05
	db &15,&00,&fc,&00,&08,&08,&00,&02,&5e
	db &00,&09,&00,&00,&04,&fc,&00,&0a,&00
	db &01,&00,&64,&00,&08,&07,&00,&02,&fc
	db &00,&09,&08,&00,&04,&7e,&00,&0a,&05
	db &17,&00,&fc,&00,&08,&08,&00,&02,&64
	db &00,&09,&00,&00,&04,&fc,&00,&0a,&00
	db &0e,&08,&00,&00,&00,&2c,&00,&01,&01
	db &00,&08,&08,&00,&02,&fc,&00,&04,&64
	db &0f,&08,&00,&01,&00,&96,&00,&01,&00
	db &00,&08,&08,&00,&02,&9f,&00,&09,&08
	db &00,&04,&2c,&00,&05,&01,&0e,&08,&00
	db &00,&09,&00,&01,&00,&7e,&00,&08,&08
	db &00,&02,&2c,&00,&03,&01,&00,&09,&08
	db &00,&04,&96,&00,&05,&00,&0e,&08,&00
	db &00,&09,&00,&01,&00,&64,&00,&08,&08
	db &00,&02,&9f,&00,&03,&00,&00,&09,&08
	db &00,&04,&7e,&0e,&08,&00,&00,&09,&00
	db &01,&08,&08,&00,&02,&2c,&00,&03,&01
	db &00,&09,&08,&00,&04,&64,&16,&00,&2c
	db &00,&01,&01,&00,&02,&64,&00,&03,&00
	db &00,&09,&00,&00,&04,&2c,&00,&05,&01
	db &00,&00,&70,&00,&01,&00,&00,&08,&08
	db &00,&02,&2c,&00,&03,&01,&00,&09,&08
	db &16,&00,&2c,&00,&01,&01,&00,&08,&08
	db &00,&02,&70,&00,&03,&00,&00,&09,&00
	db &0f,&08,&00,&00,&08,&08,&00,&02,&2c
	db &00,&03,&01,&00,&04,&70,&00,&05,&00
	db &0f,&08,&00,&01,&00,&64,&00,&01,&00
	db &00,&08,&08,&00,&02,&9f,&00,&03,&00
	db &00,&09,&08,&00,&04,&2c,&00,&05,&01
	db &0e,&08,&00,&00,&09,&00,&01,&00,&54
	db &00,&08,&08,&00,&02,&2c,&00,&03,&01
	db &00,&09,&08,&00,&04,&64,&00,&05,&00
	db &0e,&08,&00,&00,&09,&00,&01,&00,&4b
	db &00,&08,&08,&00,&02,&9f,&00,&03,&00
	db &00,&09,&08,&00,&04,&54,&0e,&08,&00
	db &00,&09,&00,&01,&00,&43,&00,&08,&08
	db &00,&02,&2c,&00,&03,&01,&00,&09,&08
	db &00,&04,&4b,&16,&00,&2c,&00,&01,&01
	db &00,&02,&43,&00,&03,&00,&00,&09,&00
	db &00,&04,&2c,&00,&05,&01,&00,&00,&4b
	db &00,&01,&00,&00,&08,&08,&00,&02,&2c
	db &00,&03,&01,&00,&09,&08,&16,&00,&2c
	db &00,&01,&01,&00,&08,&08,&00,&02,&4b
	db &00,&03,&00,&00,&09,&00,&0f,&08,&00
	db &00,&00,&54,&00,&01,&00,&00,&08,&07
	db &00,&02,&50,&00,&03,&01,&00,&09,&08
	db &00,&04,&70,&00,&05,&00,&00,&0a,&06
	db &0e,&00,&50,&00,&01,&01,&00,&08,&08
	db &00,&02,&54,&00,&03,&00,&00,&09,&00
	db &00,&04,&50,&00,&05,&01,&00,&0a,&00
	db &01,&08,&00,&01,&00,&54,&00,&01,&00
	db &00,&08,&07,&00,&02,&a8,&00,&09,&08
	db &00,&04,&70,&00,&05,&00,&00,&0a,&05
	db &0d,&00,&a8,&00,&08,&08,&00,&02,&70
	db &00,&09,&05,&00,&04,&54,&00,&0a,&00
	db &01,&00,&70,&00,&08,&05,&00,&02,&a8
	db &00,&09,&00,&00,&04,&70,&01,&00,&50
	db &00,&01,&01,&00,&08,&08,&00,&02,&70
	db &00,&09,&05,&01,&02,&50,&00,&03,&01
	db &00,&09,&00,&0a,&00,&5e,&00,&01,&00
	db &00,&08,&08,&00,&02,&70,&00,&03,&00
	db &00,&09,&07,&00,&04,&50,&00,&05,&01
	db &00,&0a,&08,&03,&04,&5e,&00,&05,&00
	db &00,&0a,&00,&01,&08,&00,&00,&09,&00
	db &00,&00,&38,&00,&08,&08,&00,&02,&43
	db &00,&09,&07,&00,&04,&a8,&00,&0a,&08
	db &0e,&08,&00,&00,&09,&00,&00,&0a,&00
	db &01,&00,&43,&00,&08,&09,&00,&02,&54
	db &00,&09,&07,&00,&04,&50,&00,&05,&01
	db &00,&0a,&08,&0e,&08,&00,&00,&09,&00
	db &00,&0a,&00,&01,&00,&a8,&00,&08,&08
	db &00,&02,&43,&00,&04,&54,&00,&05,&00
	db &07,&08,&00,&00,&00,&50,&00,&01,&01
	db &00,&08,&08,&00,&02,&a8,&00,&04,&43
	db &07,&02,&50,&00,&03,&01,&00,&04,&a8
	db &00,&08,&00,&00,&00,&85,&00,&01,&00
	db &00,&08,&08,&00,&04,&50,&00,&05,&01
	db &08,&09,&08,&00,&04,&85,&00,&05,&00
	db &03,&00,&50,&00,&01,&01,&00,&08,&08
	db &00,&02,&85,&00,&03,&00,&00,&09,&00
	db &00,&04,&50,&00,&05,&01,&01,&00,&70
	db &00,&01,&00,&00,&02,&50,&00,&03,&01
	db &00,&09,&08,&03,&02,&70,&00,&03,&00
	db &00,&09,&00,&00,&08,&00,&00,&00,&64
	db &00,&08,&08,&00,&02,&a8,&00,&09,&06
	db &00,&04,&70,&00,&05,&00,&07,&00,&a8
	db &00,&08,&06,&00,&02,&64,&00,&09,&00
	db &00,&04,&a8,&00,&00,&54,&00,&08,&08
	db &00,&02,&a8,&00,&09,&06,&07,&00,&a8
	db &00,&08,&06,&00,&02,&54,&00,&09,&00
	db &01,&00,&54,&00,&08,&08,&00,&02,&a8
	db &00,&09,&06,&00,&04,&50,&00,&05,&01
	db &00,&0a,&07,&01,&02,&50,&00,&03,&01
	db &00,&09,&07,&00,&04,&54,&00,&05,&00
	db &00,&0a,&00,&0e,&00,&50,&00,&01,&01
	db &00,&08,&07,&00,&02,&54,&00,&03,&00
	db &00,&09,&00,&00,&04,&50,&00,&05,&01
	db &01,&00,&5e,&00,&01,&00,&00,&08,&08
	db &00,&02,&a8,&00,&09,&06,&00,&0a,&07
	db &01,&04,&5e,&00,&05,&00,&00,&0a,&00
	db &0d,&00,&a8,&00,&08,&06,&00,&02,&5e
	db &00,&09,&00,&00,&04,&a8,&01,&00,&6a
	db &00,&08,&08,&00,&02,&a8,&00,&09,&06
	db &00,&04,&50,&00,&05,&01,&00,&0a,&06
	db &01,&02,&50,&00,&03,&01,&00,&09,&06
	db &00,&04,&6a,&00,&05,&00,&00,&0a,&00
	db &0d,&00,&50,&00,&01,&01,&00,&08,&06
	db &00,&02,&6a,&00,&03,&00,&00,&09,&00
	db &00,&04,&50,&00,&05,&01,&01,&00,&5e
	db &00,&01,&00,&00,&08,&08,&00,&02,&a8
	db &00,&09,&06,&00,&0a,&06,&01,&04,&5e
	db &00,&05,&00,&00,&0a,&00,&0d,&00,&a8
	db &00,&08,&06,&00,&02,&5e,&00,&09,&00
	db &00,&04,&a8,&01,&00,&54,&00,&08,&08
	db &00,&02,&a8,&00,&09,&06,&00,&04,&3d
	db &00,&05,&01,&00,&0a,&06,&01,&02,&3d
	db &00,&03,&01,&00,&09,&06,&00,&04,&54
	db &00,&05,&00,&00,&0a,&00,&0d,&00,&3d
	db &00,&01,&01,&00,&08,&06,&00,&02,&54
	db &00,&03,&00,&00,&09,&00,&00,&04,&3d
	db &00,&05,&01,&01,&00,&5e,&00,&01,&00
	db &00,&08,&08,&00,&02,&bd,&00,&09,&06
	db &00,&0a,&06,&01,&04,&5e,&00,&05,&00
	db &00,&0a,&00,&0d,&00,&bd,&00,&08,&06
	db &00,&02,&5e,&00,&09,&00,&00,&04,&bd
	db &01,&00,&6a,&00,&08,&08,&00,&02,&bd
	db &00,&09,&06,&00,&04,&3d,&00,&05,&01
	db &00,&0a,&06,&01,&02,&3d,&00,&03,&01
	db &00,&09,&06,&00,&04,&6a,&00,&05,&00
	db &00,&0a,&00,&0d,&00,&3d,&00,&01,&01
	db &00,&08,&06,&00,&02,&6a,&00,&03,&00
	db &00,&09,&00,&00,&04,&3d,&00,&05,&01
	db &01,&00,&5e,&00,&01,&00,&00,&08,&08
	db &00,&02,&bd,&00,&09,&06,&00,&0a,&06
	db &01,&04,&5e,&00,&05,&00,&00,&0a,&00
	db &0d,&00,&bd,&00,&08,&06,&00,&02,&5e
	db &00,&09,&00,&00,&04,&bd,&01,&00,&54
	db &00,&08,&08,&00,&02,&70,&00,&09,&07
	db &00,&0a,&06,&01,&04,&50,&00,&05,&01
	db &00,&0a,&07,&0e,&00,&50,&00,&01,&01
	db &00,&08,&07,&00,&02,&54,&00,&09,&00
	db &00,&04,&70,&00,&05,&00,&00,&0a,&00
	db &01,&00,&54,&00,&01,&00,&00,&08,&08
	db &00,&02,&70,&00,&09,&07,&00,&04,&a8
	db &00,&0a,&06,&0e,&00,&a8,&00,&08,&06
	db &00,&02,&54,&00,&09,&00,&00,&04,&70
	db &00,&0a,&00,&01,&02,&50,&00,&03,&01
	db &00,&09,&06,&00,&04,&a8,&01,&00,&50
	db &00,&01,&01,&00,&08,&06,&00,&02,&a8
	db &00,&03,&00,&00,&09,&00,&00,&04,&50
	db &00,&05,&01,&0a,&00,&5e,&00,&01,&00
	db &00,&08,&08,&00,&02,&70,&00,&09,&07
	db &00,&0a,&06,&03,&00,&50,&00,&01,&01
	db &00,&08,&06,&00,&02,&5e,&00,&09,&00
	db &00,&04,&70,&00,&05,&00,&00,&0a,&00
	db &00,&00,&38,&00,&01,&00,&00,&08,&08
	db &00,&02,&43,&00,&09,&07,&00,&04,&a8
	db &00,&0a,&06,&0e,&00,&a8,&00,&08,&06
	db &00,&02,&38,&00,&09,&00,&00,&04,&43
	db &00,&0a,&00,&01,&00,&43,&00,&08,&09
	db &00,&02,&54,&00,&09,&07,&00,&04,&a8
	db &00,&0a,&06,&01,&04,&50,&00,&05,&01
	db &00,&0a,&06,&0d,&00,&50,&00,&01,&01
	db &00,&08,&06,&00,&02,&43,&00,&09,&00
	db &00,&04,&54,&00,&05,&00,&00,&0a,&00
	db &01,&00,&a8,&00,&01,&00,&00,&08,&08
	db &00,&02,&50,&00,&03,&01,&00,&09,&06
	db &00,&04,&50,&00,&05,&01,&01,&02,&a8
	db &00,&03,&00,&00,&09,&00,&06,&08,&00
	db &00,&00,&50,&00,&01,&01,&00,&08,&08
	db &00,&04,&a8,&00,&05,&00,&07,&02,&50
	db &00,&03,&01,&00,&08,&00,&00,&00,&85
	db &00,&01,&00,&00,&08,&08,&00,&04,&50
	db &00,&05,&01,&08,&09,&08,&00,&04,&85
	db &00,&05,&00,&03,&00,&50,&00,&01,&01
	db &00,&08,&08,&00,&02,&85,&00,&03,&00
	db &00,&09,&00,&00,&04,&50,&00,&05,&01
	db &01,&00,&70,&00,&01,&00,&00,&02,&50
	db &00,&03,&01,&00,&09,&08,&03,&02,&70
	db &00,&03,&00,&00,&09,&00,&00,&08,&00
	db &00,&00,&64,&00,&08,&08,&00,&02,&a8
	db &00,&09,&06,&00,&04,&70,&00,&05,&00
	db &07,&00,&a8,&00,&08,&06,&00,&02,&64
	db &00,&09,&00,&00,&04,&a8,&00,&00,&54
	db &00,&08,&08,&00,&02,&a8,&00,&09,&06
	db &07,&00,&a8,&00,&08,&06,&00,&02,&54
	db &00,&09,&00,&01,&00,&54,&00,&08,&08
	db &00,&02,&a8,&00,&09,&06,&00,&04,&a8
	db &00,&05,&01,&00,&0a,&07,&01,&02,&a8
	db &00,&03,&01,&00,&09,&07,&00,&04,&54
	db &00,&05,&00,&00,&0a,&00,&0e,&00,&a8
	db &00,&01,&01,&00,&08,&07,&00,&02,&54
	db &00,&03,&00,&00,&09,&00,&00,&04,&a8
	db &00,&05,&01,&01,&00,&5e,&00,&01,&00
	db &00,&08,&08,&00,&02,&d4,&00,&09,&06
	db &00,&0a,&07,&01,&04,&5e,&00,&05,&00
	db &00,&0a,&00,&0d,&00,&d4,&00,&08,&06
	db &00,&02,&5e,&00,&09,&00,&00,&04,&d4
	db &01,&00,&6a,&00,&08,&08,&00,&02,&d4
	db &00,&09,&06,&00,&04,&a8,&00,&05,&01
	db &00,&0a,&06,&01,&02,&a8,&00,&03,&01
	db &00,&09,&06,&00,&04,&6a,&00,&05,&00
	db &00,&0a,&00,&0d,&00,&a8,&00,&01,&01
	db &00,&08,&06,&00,&02,&6a,&00,&03,&00
	db &00,&09,&00,&00,&04,&a8,&00,&05,&01
	db &01,&00,&5e,&00,&01,&00,&00,&08,&08
	db &00,&02,&d4,&00,&09,&06,&00,&0a,&06
	db &01,&04,&5e,&00,&05,&00,&00,&0a,&00
	db &0d,&00,&d4,&00,&08,&06,&00,&02,&5e
	db &00,&09,&00,&00,&04,&d4,&01,&00,&54
	db &00,&08,&08,&00,&02,&d4,&00,&09,&06
	db &00,&04,&79,&00,&05,&01,&00,&0a,&06
	db &01,&02,&79,&00,&03,&01,&00,&09,&06
	db &00,&04,&54,&00,&05,&00,&00,&0a,&00
	db &0d,&00,&79,&00,&01,&01,&00,&08,&06
	db &00,&02,&54,&00,&03,&00,&00,&09,&00
	db &00,&04,&79,&00,&05,&01,&01,&00,&5e
	db &00,&01,&00,&00,&08,&08,&00,&02,&bd
	db &00,&09,&06,&00,&0a,&06,&01,&04,&5e
	db &00,&05,&00,&00,&0a,&00,&0d,&00,&bd
	db &00,&08,&06,&00,&02,&5e,&00,&09,&00
	db &00,&04,&bd,&01,&00,&6a,&00,&08,&08
	db &00,&02,&bd,&00,&09,&06,&00,&04,&79
	db &00,&05,&01,&00,&0a,&06,&01,&02,&79
	db &00,&03,&01,&00,&09,&06,&00,&04,&6a
	db &00,&05,&00,&00,&0a,&00,&0d,&00,&79
	db &00,&01,&01,&00,&08,&06,&00,&02,&6a
	db &00,&03,&00,&00,&09,&00,&00,&04,&79
	db &00,&05,&01,&01,&00,&5e,&00,&01,&00
	db &00,&08,&08,&00,&02,&bd,&00,&09,&06
	db &00,&0a,&06,&01,&04,&5e,&00,&05,&00
	db &00,&0a,&00,&0d,&00,&bd,&00,&08,&06
	db &00,&02,&5e,&00,&09,&00,&00,&04,&bd
	db &01,&00,&54,&00,&08,&08,&00,&02,&70
	db &00,&09,&07,&00,&0a,&06,&01,&04,&50
	db &00,&05,&01,&00,&0a,&07,&0e,&00,&50
	db &00,&01,&01,&00,&08,&07,&00,&02,&54
	db &00,&09,&00,&00,&04,&70,&00,&05,&00
	db &00,&0a,&00,&01,&00,&54,&00,&01,&00
	db &00,&08,&08,&00,&02,&70,&00,&09,&07
	db &00,&04,&a8,&00,&0a,&06,&0e,&00,&a8
	db &00,&08,&06,&00,&02,&54,&00,&09,&00
	db &00,&04,&70,&00,&0a,&00,&01,&02,&50
	db &00,&03,&01,&00,&09,&06,&00,&04,&a8
	db &01,&00,&50,&00,&01,&01,&00,&08,&06
	db &00,&02,&a8,&00,&03,&00,&00,&09,&00
	db &00,&04,&50,&00,&05,&01,&0e,&00,&a8
	db &00,&01,&00,&00,&08,&06,&00,&02,&50
	db &00,&03,&01,&00,&09,&06,&01,&02,&a8
	db &00,&03,&00,&00,&09,&00,&0e,&02,&50
	db &00,&03,&01,&00,&09,&06,&00,&04,&a8
	db &00,&05,&00,&01,&00,&50,&00,&01,&01
	db &00,&08,&06,&00,&02,&a8,&00,&03,&00
	db &00,&09,&00,&00,&04,&50,&00,&05,&01
	db &0e,&02,&2c,&00,&03,&01,&00,&09,&06
	db &01,&00,&2c,&00,&08,&06,&00,&02,&50
	db &00,&09,&00,&00,&04,&2c,&0e,&00,&0b
	db &00,&08,&06,&00,&02,&2c,&00,&09,&06
	db &01,&02,&0b,&00,&09,&00,&0e,&00,&fc
	db &00,&01,&00,&00,&08,&07,&00,&09,&06
	db &00,&0a,&05,&01,&02,&2c,&00,&09,&05
	db &00,&04,&fc,&00,&05,&00,&00,&0a,&00
	db &0c,&00,&2c,&00,&01,&01,&00,&08,&05
	db &00,&02,&fc,&00,&03,&00,&00,&09,&00
	db &00,&04,&2c,&00,&05,&01,&02,&00,&e0
	db &00,&01,&00,&00,&08,&08,&00,&02,&2c
	db &00,&03,&01,&00,&09,&05,&01,&02,&e0
	db &00,&03,&00,&00,&09,&00,&07,&08,&00
	db &00,&00,&54,&00,&08,&08,&00,&02,&fc
	db &00,&09,&08,&00,&04,&e0,&00,&05,&00
	db &0e,&00,&fc,&00,&02,&54,&00,&09,&00
	db &00,&04,&fc,&01,&00,&54,&00,&02,&fc
	db &00,&09,&08,&07,&00,&fc,&00,&02,&54
	db &00,&09,&00,&00,&08,&00,&00,&00,&43
	db &00,&08,&08,&00,&02,&2c,&00,&03,&01
	db &00,&09,&08,&0e,&00,&2c,&00,&01,&01
	db &00,&02,&43,&00,&03,&00,&00,&09,&00
	db &00,&04,&2c,&00,&05,&01,&01,&00,&54
	db &00,&01,&00,&00,&08,&08,&00,&02,&2c
	db &00,&03,&01,&00,&09,&08,&0e,&00,&2c
	db &00,&01,&01,&00,&08,&08,&00,&02,&54
	db &00,&03,&00,&00,&09,&00,&01,&08,&00
	db &00,&00,&70,&00,&01,&00,&00,&08,&08
	db &00,&02,&0b,&00,&03,&01,&00,&09,&08
	db &0e,&00,&0b,&00,&01,&01,&00,&02,&70
	db &00,&03,&00,&00,&09,&00,&00,&04,&0b
	db &01,&00,&64,&00,&01,&00,&00,&08,&08
	db &00,&02,&0b,&00,&03,&01,&00,&09,&08
	db &0e,&00,&0b,&00,&01,&01,&00,&08,&08
	db &00,&02,&64,&00,&03,&00,&00,&09,&00
	db &01,&08,&00,&00,&00,&54,&00,&01,&00
	db &00,&08,&08,&00,&02,&0b,&00,&03,&01
	db &00,&09,&08,&1e,&08,&00,&00,&09,&00
	db &00,&08,&07,&00,&02,&79,&00,&09,&08
	db &00,&04,&54,&00,&05,&00,&07,&00,&79
	db &00,&01,&01,&00,&08,&08,&00,&02,&54
	db &00,&03,&00,&00,&09,&00,&00,&04,&79
	db &00,&05,&01,&01,&00,&54,&00,&01,&00
	db &00,&08,&06,&00,&02,&79,&00,&03,&01
	db &00,&09,&08,&06,&02,&54,&00,&03,&00
	db &00,&09,&00,&01,&00,&43,&00,&08,&08
	db &00,&09,&06,&00,&0a,&08,&00,&02,&79
	db &00,&03,&01,&00,&09,&08,&00,&04,&43
	db &00,&05,&00,&00,&0a,&00,&06,&02,&43
	db &00,&03,&00,&00,&09,&00,&00,&04,&79
	db &00,&05,&01,&07,&08,&00,&01,&00,&54
	db &00,&08,&08,&00,&02,&50,&00,&03,&01
	db &00,&09,&08,&00,&04,&43,&00,&05,&00
	db &0e,&00,&50,&00,&01,&01,&00,&02,&54
	db &00,&03,&00,&00,&09,&00,&00,&04,&50
	db &00,&05,&01,&01,&00,&43,&00,&01,&00
	db &00,&08,&08,&00,&02,&50,&00,&03,&01
	db &00,&09,&08,&0e,&00,&50,&00,&01,&01
	db &00,&08,&08,&00,&02,&43,&00,&03,&00
	db &00,&09,&00,&01,&08,&00,&00,&00,&3f
	db &00,&01,&00,&00,&08,&08,&00,&02,&50
	db &00,&03,&01,&00,&09,&08,&0e,&00,&50
	db &00,&01,&01,&00,&02,&3f,&00,&03,&00
	db &00,&09,&00,&01,&00,&43,&00,&01,&00
	db &00,&08,&08,&00,&02,&50,&00,&03,&01
	db &00,&09,&08,&0e,&00,&50,&00,&01,&01
	db &00,&08,&08,&00,&02,&43,&00,&03,&00
	db &00,&09,&00,&01,&08,&00,&00,&00,&54
	db &00,&01,&00,&00,&08,&08,&00,&02,&90
	db &00,&03,&01,&00,&09,&08,&16,&02,&54
	db &00,&03,&00,&00,&09,&00,&00,&04,&90
	db &08,&08,&00,&00,&00,&90,&00,&01,&01
	db &00,&08,&08,&00,&04,&54,&00,&05,&00
	db &09,&00,&4b,&00,&01,&00,&00,&08,&08
	db &00,&02,&90,&00,&03,&01,&00,&09,&08
	db &00,&04,&90,&00,&05,&01,&0e,&00,&90
	db &00,&01,&01,&00,&08,&08,&00,&02,&4b
	db &00,&03,&00,&00,&09,&00,&01,&08,&00
	db &00,&00,&4b,&00,&01,&00,&00,&08,&08
	db &00,&02,&90,&00,&03,&01,&00,&04,&4b
	db &00,&05,&00,&07,&08,&00,&00,&08,&08
	db &00,&09,&08,&0e,&00,&90,&00,&01,&01
	db &00,&02,&4b,&00,&03,&00,&00,&09,&00
	db &00,&04,&90,&00,&05,&01,&01,&00,&43
	db &00,&01,&00,&00,&08,&08,&00,&02,&90
	db &00,&03,&01,&00,&09,&08,&0e,&00,&90
	db &00,&01,&01,&00,&08,&08,&00,&02,&43
	db &00,&03,&00,&00,&09,&00,&01,&08,&00
	db &00,&00,&3b,&00,&01,&00,&00,&08,&08
	db &00,&02,&d4,&00,&09,&08,&0e,&08,&00
	db &00,&09,&00,&01,&00,&43,&00,&08,&08
	db &00,&09,&08,&00,&04,&3b,&00,&05,&00
	db &0e,&08,&00,&00,&09,&00,&01,&00,&4b
	db &00,&08,&08,&00,&09,&08,&00,&04,&43
	db &0e,&08,&00,&00,&09,&00,&01,&00,&43
	db &00,&08,&08,&00,&09,&08,&00,&04,&4b
	db &0e,&08,&00,&00,&09,&00,&01,&00,&4b
	db &00,&08,&08,&00,&02,&64,&00,&09,&07
	db &00,&04,&2c,&00,&05,&01,&00,&0a,&08
	db &0f,&08,&00,&00,&09,&00,&00,&0a,&00
	db &01,&08,&08,&00,&02,&9f,&00,&09,&08
	db &00,&04,&64,&00,&05,&00,&00,&0a,&07
	db &0e,&08,&00,&00,&09,&00,&00,&0a,&00
	db &01,&00,&2c,&00,&01,&01,&00,&08,&08
	db &00,&02,&4b,&00,&04,&9f,&0b,&00,&4b
	db &00,&01,&00,&00,&08,&08,&00,&02,&64
	db &00,&09,&07,&00,&04,&2c,&00,&05,&01
	db &00,&0a,&08,&03,&04,&4b,&00,&05,&00
	db &00,&0a,&00,&01,&08,&00,&00,&09,&00
	db &00,&00,&35,&00,&08,&08,&00,&02,&3b
	db &00,&09,&07,&00,&04,&9f,&00,&0a,&08
	db &0e,&08,&00,&00,&09,&00,&00,&0a,&00
	db &01,&00,&3b,&00,&08,&09,&00,&02,&4b
	db &00,&09,&07,&00,&04,&2c,&00,&05,&01
	db &00,&0a,&08,&0e,&08,&00,&00,&09,&00
	db &00,&0a,&00,&01,&00,&96,&00,&08,&08
	db &00,&02,&9f,&00,&09,&08,&00,&04,&3b
	db &00,&05,&00,&07,&02,&96,&00,&09,&00
	db &00,&04,&9f,&00,&02,&2c,&00,&03,&01
	db &00,&09,&08,&00,&04,&96,&07,&00,&2c
	db &00,&01,&01,&00,&02,&96,&00,&03,&00
	db &00,&09,&00,&00,&04,&2c,&00,&05,&01
	db &00,&08,&00,&00,&00,&77,&00,&01,&00
	db &00,&08,&08,&00,&02,&2c,&00,&03,&01
	db &00,&04,&96,&00,&05,&00,&08,&09,&08
	db &00,&04,&77,&03,&00,&2c,&00,&01,&01
	db &00,&08,&08,&00,&02,&77,&00,&03,&00
	db &00,&09,&00,&00,&04,&2c,&00,&05,&01
	db &01,&00,&64,&00,&01,&00,&00,&02,&2c
	db &00,&03,&01,&00,&09,&08,&03,&02,&64
	db &00,&03,&00,&00,&09,&00,&00,&08,&00
	db &00,&00,&59,&00,&08,&08,&00,&02,&9f
	db &00,&09,&06,&00,&04,&64,&00,&05,&00
	db &07,&00,&9f,&00,&08,&06,&00,&02,&59
	db &00,&09,&00,&00,&04,&9f,&00,&00,&4b
	db &00,&08,&08,&00,&02,&9f,&00,&09,&06
	db &07,&00,&9f,&00,&08,&06,&00,&02,&4b
	db &00,&09,&00,&01,&00,&4b,&00,&08,&08
	db &00,&02,&9f,&00,&09,&06,&00,&04,&79
	db &00,&05,&01,&00,&0a,&07,&01,&02,&79
	db &00,&03,&01,&00,&09,&07,&00,&04,&4b
	db &00,&05,&00,&00,&0a,&00,&0e,&00,&79
	db &00,&01,&01,&00,&08,&07,&00,&02,&4b
	db &00,&03,&00,&00,&09,&00,&00,&04,&79
	db &00,&05,&01,&01,&00,&54,&00,&01,&00
	db &00,&08,&08,&00,&02,&bd,&00,&09,&06
	db &00,&0a,&07,&01,&04,&54,&00,&05,&00
	db &00,&0a,&00,&0d,&00,&bd,&00,&08,&06
	db &00,&02,&54,&00,&09,&00,&00,&04,&bd
	db &01,&00,&5e,&00,&08,&08,&00,&02,&bd
	db &00,&09,&06,&00,&04,&79,&00,&05,&01
	db &00,&0a,&06,&01,&02,&79,&00,&03,&01
	db &00,&09,&06,&00,&04,&5e,&00,&05,&00
	db &00,&0a,&00,&0d,&00,&79,&00,&01,&01
	db &00,&08,&06,&00,&02,&5e,&00,&03,&00
	db &00,&09,&00,&00,&04,&79,&00,&05,&01
	db &01,&00,&54,&00,&01,&00,&00,&08,&08
	db &00,&02,&bd,&00,&09,&06,&00,&0a,&06
	db &01,&04,&54,&00,&05,&00,&00,&0a,&00
	db &0d,&00,&bd,&00,&08,&06,&00,&02,&54
	db &00,&09,&00,&00,&04,&bd,&01,&00,&4b
	db &00,&08,&08,&00,&02,&bd,&00,&09,&06
	db &00,&04,&50,&00,&05,&01,&00,&0a,&06
	db &01,&02,&50,&00,&03,&01,&00,&09,&06
	db &00,&04,&4b,&00,&05,&00,&00,&0a,&00
	db &0d,&00,&50,&00,&01,&01,&00,&08,&06
	db &00,&02,&4b,&00,&03,&00,&00,&09,&00
	db &00,&04,&50,&00,&05,&01,&01,&00,&54
	db &00,&01,&00,&00,&08,&08,&00,&02,&a8
	db &00,&09,&06,&00,&0a,&06,&01,&04,&54
	db &00,&05,&00,&00,&0a,&00,&0d,&00,&a8
	db &00,&08,&06,&00,&02,&54,&00,&09,&00
	db &00,&04,&a8,&01,&00,&5e,&00,&08,&08
	db &00,&02,&a8,&00,&09,&06,&00,&04,&50
	db &00,&05,&01,&00,&0a,&06,&01,&02,&50
	db &00,&03,&01,&00,&09,&06,&00,&04,&5e
	db &00,&05,&00,&00,&0a,&00,&0d,&00,&50
	db &00,&01,&01,&00,&08,&06,&00,&02,&5e
	db &00,&03,&00,&00,&09,&00,&00,&04,&50
	db &00,&05,&01,&01,&00,&54,&00,&01,&00
	db &00,&08,&08,&00,&02,&a8,&00,&09,&06
	db &00,&0a,&06,&01,&04,&54,&00,&05,&00
	db &00,&0a,&00,&0d,&00,&a8,&00,&08,&06
	db &00,&02,&54,&00,&09,&00,&00,&04,&a8
	db &01,&00,&4b,&00,&08,&08,&00,&02,&64
	db &00,&09,&07,&00,&0a,&06,&01,&04,&2c
	db &00,&05,&01,&00,&0a,&07,&0e,&00,&2c
	db &00,&01,&01,&00,&08,&07,&00,&02,&4b
	db &00,&09,&00,&00,&04,&64,&00,&05,&00
	db &00,&0a,&00,&01,&00,&4b,&00,&01,&00
	db &00,&08,&08,&00,&02,&64,&00,&09,&07
	db &00,&04,&9f,&00,&0a,&06,&0e,&00,&9f
	db &00,&08,&06,&00,&02,&4b,&00,&09,&00
	db &00,&04,&64,&00,&0a,&00,&01,&02,&2c
	db &00,&03,&01,&00,&09,&06,&00,&04,&9f
	db &01,&00,&2c,&00,&01,&01,&00,&08,&06
	db &00,&02,&9f,&00,&03,&00,&00,&09,&00
	db &00,&04,&2c,&00,&05,&01,&0a,&00,&4b
	db &00,&01,&00,&00,&08,&08,&00,&02,&64
	db &00,&09,&07,&00,&0a,&06,&03,&00,&2c
	db &00,&01,&01,&00,&08,&06,&00,&02,&4b
	db &00,&09,&00,&00,&04,&64,&00,&05,&00
	db &00,&0a,&00,&00,&00,&35,&00,&01,&00
	db &00,&08,&08,&00,&02,&3b,&00,&09,&07
	db &00,&04,&9f,&00,&0a,&06,&0e,&00,&9f
	db &00,&08,&06,&00,&02,&35,&00,&09,&00
	db &00,&04,&3b,&00,&0a,&00,&01,&00,&3b
	db &00,&08,&09,&00,&02,&4b,&00,&09,&07
	db &00,&04,&9f,&00,&0a,&06,&01,&04,&2c
	db &00,&05,&01,&00,&0a,&06,&0d,&00,&2c
	db &00,&01,&01,&00,&08,&06,&00,&02,&3b
	db &00,&09,&00,&00,&04,&4b,&00,&05,&00
	db &00,&0a,&00,&01,&00,&4b,&00,&01,&00
	db &00,&08,&08,&00,&02,&9f,&00,&09,&08
	db &00,&04,&2c,&00,&05,&01,&00,&0a,&06
	db &01,&04,&4b,&00,&05,&00,&00,&0a,&00
	db &06,&02,&4b,&00,&09,&00,&00,&04,&9f
	db &00,&02,&2c,&00,&03,&01,&00,&09,&08
	db &00,&04,&4b,&07,&00,&2c,&00,&01,&01
	db &00,&02,&4b,&00,&03,&00,&00,&09,&00
	db &00,&04,&2c,&00,&05,&01,&00,&08,&00
	db &00,&00,&3b,&00,&01,&00,&00,&08,&08
	db &00,&02,&2c,&00,&03,&01,&00,&04,&4b
	db &00,&05,&00,&07,&08,&00,&00,&00,&43
	db &00,&08,&08,&00,&09,&08,&00,&04,&3b
	db &03,&00,&2c,&00,&01,&01,&00,&02,&43
	db &00,&03,&00,&00,&09,&00,&00,&04,&2c
	db &00,&05,&01,&00,&00,&4b,&00,&01,&00
	db &00,&02,&2c,&00,&03,&01,&00,&09,&08
	db &03,&02,&4b,&00,&03,&00,&00,&09,&00
	db &00,&08,&00,&00,&00,&54,&00,&08,&08
	db &00,&02,&9f,&00,&09,&06,&00,&04,&4b
	db &00,&05,&00,&07,&00,&9f,&00,&08,&06
	db &00,&02,&54,&00,&09,&00,&00,&04,&9f
	db &00,&00,&4b,&00,&08,&08,&00,&02,&9f
	db &00,&09,&06,&07,&00,&9f,&00,&08,&06
	db &00,&02,&4b,&00,&09,&00,&01,&00,&4b
	db &00,&08,&08,&00,&02,&9f,&00,&09,&06
	db &00,&04,&79,&00,&05,&01,&00,&0a,&07
	db &01,&02,&79,&00,&03,&01,&00,&09,&07
	db &00,&04,&4b,&00,&05,&00,&00,&0a,&00
	db &0e,&00,&79,&00,&01,&01,&00,&08,&07
	db &00,&02,&4b,&00,&03,&00,&00,&09,&00
	db &00,&04,&79,&00,&05,&01,&01,&00,&54
	db &00,&01,&00,&00,&08,&08,&00,&02,&bd
	db &00,&09,&06,&00,&0a,&07,&01,&04,&54
	db &00,&05,&00,&00,&0a,&00,&0d,&00,&bd
	db &00,&08,&06,&00,&02,&54,&00,&09,&00
	db &00,&04,&bd,&01,&00,&5e,&00,&08,&08
	db &00,&02,&bd,&00,&09,&06,&00,&04,&79
	db &00,&05,&01,&00,&0a,&06,&01,&02,&79
	db &00,&03,&01,&00,&09,&06,&00,&04,&5e
	db &00,&05,&00,&00,&0a,&00,&0d,&00,&79
	db &00,&01,&01,&00,&08,&06,&00,&02,&5e
	db &00,&03,&00,&00,&09,&00,&00,&04,&79
	db &00,&05,&01,&01,&00,&54,&00,&01,&00
	db &00,&08,&08,&00,&02,&bd,&00,&09,&06
	db &00,&0a,&06,&01,&04,&54,&00,&05,&00
	db &00,&0a,&00,&0d,&00,&bd,&00,&08,&06
	db &00,&02,&54,&00,&09,&00,&00,&04,&bd
	db &01,&00,&4b,&00,&08,&08,&00,&02,&bd
	db &00,&09,&06,&00,&04,&50,&00,&05,&01
	db &00,&0a,&06,&01,&02,&50,&00,&03,&01
	db &00,&09,&06,&00,&04,&4b,&00,&05,&00
	db &00,&0a,&00,&0d,&00,&50,&00,&01,&01
	db &00,&08,&06,&00,&02,&4b,&00,&03,&00
	db &00,&09,&00,&00,&04,&50,&00,&05,&01
	db &01,&00,&54,&00,&01,&00,&00,&08,&08
	db &00,&02,&a8,&00,&09,&06,&00,&0a,&06
	db &01,&04,&54,&00,&05,&00,&00,&0a,&00
	db &0d,&00,&a8,&00,&08,&06,&00,&02,&54
	db &00,&09,&00,&00,&04,&a8,&01,&00,&5e
	db &00,&08,&08,&00,&02,&a8,&00,&09,&06
	db &00,&04,&50,&00,&05,&01,&00,&0a,&06
	db &01,&02,&50,&00,&03,&01,&00,&09,&06
	db &00,&04,&5e,&00,&05,&00,&00,&0a,&00
	db &0d,&00,&50,&00,&01,&01,&00,&08,&06
	db &00,&02,&5e,&00,&03,&00,&00,&09,&00
	db &00,&04,&50,&00,&05,&01,&01,&00,&54
	db &00,&01,&00,&00,&08,&08,&00,&02,&a8
	db &00,&09,&06,&00,&0a,&06,&01,&04,&54
	db &00,&05,&00,&00,&0a,&00,&0d,&00,&a8
	db &00,&08,&06,&00,&02,&54,&00,&09,&00
	db &00,&04,&a8,&01,&00,&4b,&00,&08,&08
	db &00,&02,&64,&00,&09,&07,&00,&0a,&06
	db &01,&04,&2c,&00,&05,&01,&00,&0a,&07
	db &0e,&00,&2c,&00,&01,&01,&00,&08,&07
	db &00,&02,&4b,&00,&09,&00,&00,&04,&64
	db &00,&05,&00,&00,&0a,&00,&01,&00,&4b
	db &00,&01,&00,&00,&08,&08,&00,&02,&64
	db &00,&09,&07,&00,&04,&9f,&00,&0a,&06
	db &0e,&00,&9f,&00,&08,&06,&00,&02,&4b
	db &00,&09,&00,&00,&04,&64,&00,&0a,&00
	db &01,&02,&2c,&00,&03,&01,&00,&09,&06
	db &00,&04,&9f,&01,&00,&2c,&00,&01,&01
	db &00,&08,&06,&00,&02,&9f,&00,&03,&00
	db &00,&09,&00,&00,&04,&2c,&00,&05,&01
	db &0a,&00,&4b,&00,&01,&00,&00,&08,&08
	db &00,&02,&64,&00,&09,&07,&00,&0a,&06
	db &03,&00,&2c,&00,&01,&01,&00,&08,&06
	db &00,&02,&4b,&00,&09,&00,&00,&04,&64
	db &00,&05,&00,&00,&0a,&00,&00,&00,&35
	db &00,&01,&00,&00,&08,&08,&00,&02,&3b
	db &00,&09,&07,&00,&04,&9f,&00,&0a,&06
	db &0e,&00,&9f,&00,&08,&06,&00,&02,&35
	db &00,&09,&00,&00,&04,&3b,&00,&0a,&00
	db &01,&00,&3b,&00,&08,&09,&00,&02,&4b
	db &00,&09,&07,&00,&04,&9f,&00,&0a,&06
	db &01,&04,&2c,&00,&05,&01,&00,&0a,&06
	db &0d,&00,&2c,&00,&01,&01,&00,&08,&06
	db &00,&02,&3b,&00,&09,&00,&00,&04,&4b
	db &00,&05,&00,&00,&0a,&00,&01,&00,&43
	db &00,&01,&00,&00,&08,&08,&00,&02,&9f
	db &00,&09,&08,&00,&04,&2c,&00,&05,&01
	db &00,&0a,&06,&01,&04,&43,&00,&05,&00
	db &00,&0a,&00,&06,&02,&43,&00,&09,&00
	db &00,&04,&9f,&00,&02,&2c,&00,&03,&01
	db &00,&09,&08,&00,&04,&43,&03,&00,&2c
	db &00,&01,&01,&00,&02,&43,&00,&03,&00
	db &00,&09,&00,&00,&04,&2c,&00,&05,&01
	db &01,&00,&4b,&00,&01,&00,&00,&02,&2c
	db &00,&03,&01,&00,&09,&08,&03,&02,&4b
	db &00,&03,&00,&00,&09,&00,&00,&08,&00
	db &00,&00,&3b,&00,&08,&08,&00,&04,&4b
	db &00,&05,&00,&08,&02,&2c,&00,&03,&01
	db &00,&09,&08,&00,&04,&3b,&03,&00,&2c
	db &00,&01,&01,&00,&08,&08,&00,&02,&3b
	db &00,&03,&00,&00,&09,&00,&00,&04,&2c
	db &00,&05,&01,&01,&00,&32,&00,&01,&00
	db &00,&02,&2c,&00,&03,&01,&00,&09,&08
	db &03,&02,&32,&00,&03,&00,&00,&09,&00
	db &00,&02,&9f,&00,&09,&06,&00,&04,&32
	db &00,&05,&00,&0f,&00,&9f,&00,&08,&06
	db &00,&02,&32,&00,&09,&00,&00,&04,&9f
	db &00,&00,&4b,&00,&08,&08,&00,&02,&9f
	db &00,&09,&06,&00,&04,&79,&00,&05,&01
	db &00,&0a,&07,&01,&02,&79,&00,&03,&01
	db &00,&09,&07,&00,&04,&4b,&00,&05,&00
	db &00,&0a,&00,&0e,&00,&79,&00,&01,&01
	db &00,&08,&07,&00,&02,&4b,&00,&03,&00
	db &00,&09,&00,&00,&04,&79,&00,&05,&01
	db &01,&00,&54,&00,&01,&00,&00,&08,&08
	db &00,&02,&bd,&00,&09,&06,&00,&0a,&07
	db &01,&04,&54,&00,&05,&00,&00,&0a,&00
	db &0d,&00,&bd,&00,&08,&06,&00,&02,&54
	db &00,&09,&00,&00,&04,&bd,&01,&00,&5e
	db &00,&08,&08,&00,&02,&bd,&00,&09,&06
	db &00,&04,&79,&00,&05,&01,&00,&0a,&06
	db &01,&02,&79,&00,&03,&01,&00,&09,&06
	db &00,&04,&5e,&00,&05,&00,&00,&0a,&00
	db &0d,&00,&79,&00,&01,&01,&00,&08,&06
	db &00,&02,&5e,&00,&03,&00,&00,&09,&00
	db &00,&04,&79,&00,&05,&01,&01,&00,&54
	db &00,&01,&00,&00,&08,&08,&00,&02,&bd
	db &00,&09,&06,&00,&0a,&06,&01,&04,&54
	db &00,&05,&00,&00,&0a,&00,&0d,&00,&bd
	db &00,&08,&06,&00,&02,&54,&00,&09,&00
	db &00,&04,&bd,&01,&00,&4b,&00,&08,&08
	db &00,&02,&bd,&00,&09,&06,&00,&04,&50
	db &00,&05,&01,&00,&0a,&06,&01,&02,&50
	db &00,&03,&01,&00,&09,&06,&00,&04,&4b
	db &00,&05,&00,&00,&0a,&00,&0d,&00,&50
	db &00,&01,&01,&00,&08,&06,&00,&02,&4b
	db &00,&03,&00,&00,&09,&00,&00,&04,&50
	db &00,&05,&01,&01,&00,&54,&00,&01,&00
	db &00,&08,&08,&00,&02,&a8,&00,&09,&06
	db &00,&0a,&06,&01,&04,&54,&00,&05,&00
	db &00,&0a,&00,&0d,&00,&a8,&00,&08,&06
	db &00,&02,&54,&00,&09,&00,&00,&04,&a8
	db &01,&00,&5e,&00,&08,&08,&00,&02,&a8
	db &00,&09,&06,&00,&04,&50,&00,&05,&01
	db &00,&0a,&06,&01,&02,&50,&00,&03,&01
	db &00,&09,&06,&00,&04,&5e,&00,&05,&00
	db &00,&0a,&00,&0d,&00,&50,&00,&01,&01
	db &00,&08,&06,&00,&02,&5e,&00,&03,&00
	db &00,&09,&00,&00,&04,&50,&00,&05,&01
	db &01,&00,&54,&00,&01,&00,&00,&08,&08
	db &00,&02,&a8,&00,&09,&06,&00,&0a,&06
	db &01,&04,&54,&00,&05,&00,&00,&0a,&00
	db &0d,&00,&a8,&00,&08,&06,&00,&02,&54
	db &00,&09,&00,&00,&04,&a8,&01,&00,&4b
	db &00,&08,&08,&00,&02,&64,&00,&09,&07
	db &00,&0a,&06,&01,&04,&2c,&00,&05,&01
	db &00,&0a,&07,&0e,&00,&2c,&00,&01,&01
	db &00,&08,&07,&00,&02,&4b,&00,&09,&00
	db &00,&04,&64,&00,&05,&00,&00,&0a,&00
	db &01,&00,&4b,&00,&01,&00,&00,&08,&08
	db &00,&02,&64,&00,&09,&07,&00,&04,&9f
	db &00,&0a,&06,&0e,&00,&9f,&00,&08,&06
	db &00,&02,&4b,&00,&09,&00,&00,&04,&64
	db &00,&0a,&00,&01,&02,&2c,&00,&03,&01
	db &00,&09,&06,&00,&04,&9f,&01,&00,&2c
	db &00,&01,&01,&00,&08,&06,&00,&02,&9f
	db &00,&03,&00,&00,&09,&00,&00,&04,&2c
	db &00,&05,&01,&0a,&00,&4b,&00,&01,&00
	db &00,&08,&08,&00,&02,&64,&00,&09,&07
	db &00,&0a,&06,&03,&00,&2c,&00,&01,&01
	db &00,&08,&06,&00,&02,&4b,&00,&09,&00
	db &00,&04,&64,&00,&05,&00,&00,&0a,&00
	db &00,&00,&35,&00,&01,&00,&00,&08,&08
	db &00,&02,&3b,&00,&09,&07,&00,&04,&9f
	db &00,&0a,&06,&0e,&00,&9f,&00,&08,&06
	db &00,&02,&35,&00,&09,&00,&00,&04,&3b
	db &00,&0a,&00,&01,&00,&3b,&00,&08,&09
	db &00,&02,&4b,&00,&09,&07,&00,&04,&9f
	db &00,&0a,&06,&01,&04,&3b,&00,&0a,&00
	db &0d,&08,&00,&00,&09,&00,&01,&00,&2c
	db &00,&01,&01,&00,&08,&06,&00,&02,&3b
	db &00,&04,&4b,&0f,&00,&1f,&00,&01,&00
	db &00,&08,&08,&00,&02,&4b,&00,&09,&07
	db &00,&04,&2c,&00,&05,&01,&00,&0a,&06
	db &01,&04,&1f,&00,&05,&00,&00,&0a,&00
	db &1d,&08,&00,&00,&09,&00,&00,&ff,&00
;; end