; ADDITIONAL ROUTINES FOR PLUS CART

; JUMP TABLE FOR FUNCTIONS AT START OF ROM
; IN ORDER TO MAKE MAIN PROGRAM FUNCTIONS CALLABLE FROM CART,
; WE NEED A JUMP TABLE IN RAM

org &C000 ; START OF ROM ADDRESS IN MEMORY

statusbarprintparagraph equ &0C00+430                 ; JUMP TABLE FUNCTIONS
checknokeyspressed      equ statusbarprintparagraph+3
waityesno               equ checknokeyspressed+3

; WRITING TO C000 SHOULD BE OK AS LONG AS THE MAIN PROGRAM CODE DOES NOT USE THIS MEMORY
; OTHERWISE WE NEED TO MAKE SURE WE USE VARIABLES ALLOCATED BY THE MAIN CODE

; CARTRIDGE FUNCTIONS JUMP TABLE
romfunctiontable:
  jp newsaloongame
  
newsaloongame:
  ld hl,str_askplaypoker
  call askyesnoplayer
  jr nz,playthegame
ret
  
playthegame:
  ld hl,str_dealhand
  call statusbarprintparagraph
  call drawcard1
  ret

str_askplaypoker: defb "DO YOU WANT TO PLAY POKER?",255
str_dealhand:     defb "HERE ARE YOUR CARDS",255

askyesnoplayer:
  call statusbarprintparagraph
  call checknokeyspressed ; PAUSE TO MAKE SURE PLAYER ISN'T HOLDING DOWN KEYS
  call waityesno
  cp "n"
ret

; PLAYER CARDS / COMPUTER CARDS
; -----------------------------
; 
; CARDS - A RANDOM NUMBER BETWEEN 0 AND 12
; SUITS - A RANDOM NUMBER BETWEEN 0 AND 3 (HEART, CLUB, DIAMOND, SPADE)
; AFTER CARDS HAVE BEEN DEALT, ARRANGE IN SUIT ORDER FOR CALCULATING WHICH HAND WINS

playercards:   defb 0,0,0,0,0
playersuits:   defb 0,0,0,0,0
computercards: defb 0,0,0,0,0
computersuits: defb 0,0,0,0,0

; DRAW CARD ON SCREEN
; -------------------

screenadr equ &8000

drawcard1:
  ld hl,screenadr+807
  call drawcard
  ld hl,screenadr+821
  call drawcard
  ld hl,screenadr+835
  call drawcard
  ld hl,screenadr+849
  call drawcard
  ld hl,screenadr+863
  drawcard:
  ld a,&0C
  call DrawHorizLineCard
  ld a,&C0 ; WHITE LINE
  ld b,40
  drawcardloop:
    push bc
    call DrawHorizLineCard
	pop bc
  djnz drawcardloop
  ld a,&0C
  call DrawHorizLineCard
  ret

; GRAPHICS FUNCTIONS
; ------------------

scr_next_line_hl:
  ld a,h
  add &08
  ld h,a

  ; CHECK IF WE WENT PAST END OF SCREEN
  sub &c0   ; IF USING &8000 FOR SCREEN MEM
  ret c

  ld bc,&C050
  add hl,bc
ret

; DRAW A LINE THE WIDTH OF THE CARD
; INPUTS
; HL = SCREEN MEMORY LOCATION
; A = LINE COLOUR
; A PRESERVED
DrawHorizLineCard:
  push af
  push hl
  ld (hl),a ; LINE COL
  push hl ; COPY HL TO DE
  pop de 
  inc e
  call ldicard
  pop hl
  call scr_next_line_hl
  pop af
ret

; DRAW A LINE THE WIDTH OF THE CARD
ldicard:
  ldi
  ldi
  ldi
  ldi
  ldi
  ldi
  ldi
  ldi
  ret
  
; IMAGES
; ---------------------------------

cardclubimg:
        DB      #00, #00, #00, #00
        DB      #00, #00, #00, #00
        DB      #00, #04, #08, #00
        DB      #00, #0C, #0C, #00
        DB      #00, #0C, #0C, #00
        DB      #00, #0C, #0C, #00
        DB      #04, #04, #08, #08
		DB      #0C, #0C, #0C, #0C
		DB      #0C, #0C, #0C, #0C
		DB      #0C, #0C, #0C, #0C
		DB      #0C, #0C, #0C, #0C
        DB      #04, #04, #08, #08
        DB      #00, #04, #08, #00
        DB      #00, #0C, #0C, #00
        DB      #00, #00, #00, #00
        DB      #00, #00, #00, #00
		
carddiamondimg:
        DB      #00, #00, #00, #00
        DB      #00, #00, #00, #00
        DB      #00, #10, #20, #00
        DB      #00, #10, #20, #00
        DB      #00, #30, #30, #00
        DB      #00, #30, #30, #00
        DB      #10, #30, #30, #20
        DB      #10, #30, #30, #20
        DB      #10, #30, #30, #20
        DB      #00, #30, #30, #00
        DB      #00, #30, #30, #00
        DB      #00, #10, #20, #00
        DB      #00, #10, #20, #00
        DB      #00, #00, #00, #00
        DB      #00, #00, #00, #00
        DB      #00, #00, #00, #00
		
cardheartimg:
        DB      #00, #00, #00, #00
        DB      #00, #00, #00, #00
        DB      #10, #20, #10, #20
        DB      #10, #20, #10, #20
        DB      #30, #30, #30, #30
        DB      #30, #30, #30, #30
        DB      #30, #30, #30, #30
        DB      #10, #30, #30, #20
        DB      #10, #30, #30, #20
        DB      #10, #30, #30, #20
        DB      #00, #30, #30, #00
        DB      #00, #30, #30, #00
        DB      #00, #10, #20, #00
        DB      #00, #10, #20, #00
        DB      #00, #00, #00, #00
        DB      #00, #00, #00, #00
		
cardspadeimg:
        DB      #00, #00, #00, #00
        DB      #00, #00, #00, #00
        DB      #00, #04, #08, #00
        DB      #00, #04, #08, #00
        DB      #00, #0C, #0C, #00
        DB      #00, #0C, #0C, #00
        DB      #04, #0C, #0C, #08
		DB      #0C, #0C, #0C, #0C
		DB      #0C, #0C, #0C, #0C
		DB      #0C, #0C, #0C, #0C
		DB      #0C, #0C, #0C, #0C
        DB      #04, #0C, #0C, #08
        DB      #04, #04, #08, #08
        DB      #00, #04, #08, #00
        DB      #00, #0C, #0C, #00
        DB      #00, #00, #00, #00
        DB      #00, #00, #00, #00
		
		
