; ADDITIONAL ROUTINES FOR PLUS CART

; JUMP TABLE FOR FUNCTIONS AT START OF ROM
; IN ORDER TO MAKE MAIN PROGRAM FUNCTIONS CALLABLE FROM CART,
; WE NEED A JUMP TABLE IN RAM

org &C000 ; START OF ROM ADDRESS IN MEMORY

; = &0DAE - JUMP TABLE FUNCTIONS
statusbarprintparagraph         equ &0C00+430 ; 0DAE
checknokeyspressed              equ statusbarprintparagraph+3
waityesno                       equ checknokeyspressed+3
randmax                         equ waityesno+3
gra_wr_string2                  equ randmax+3
waitoption_1_2_3_4_5ss          equ gra_wr_string2+3
clearmenu                       equ waitoption_1_2_3_4_5ss+3
statusbarprintparagraphnoscroll equ clearmenu+3
updatestatusbarmoney            equ statusbarprintparagraphnoscroll+3
waitspace                       equ updatestatusbarmoney+3
genrandommanname                equ waitspace+3

; FIXED POINTERS TO GAME DATA
tiletabley						equ &0A00
gamemap2						equ tiletabley+256        ; 10x10 = 100 BYTES
scr_addr_table					equ gamemap2+256          ; SIZE 200 * 2
player_cash2					equ scr_addr_table+400    ; SIZE 2 BYTES

; PLAYER CARDS / COMPUTER CARDS
; -----------------------------
; 
; CARDS - A RANDOM NUMBER BETWEEN 0 AND 51 (HEART, CLUB, DIAMOND, SPADE)
; AFTER CARDS HAVE BEEN DEALT, ARRANGE IN SUIT ORDER FOR CALCULATING WHICH HAND WINS

;              A,2,3,4,5,6,7,8,9,10,J,Q,K
cartdataarea equ &0DD0 ;statusbarprintparagraph+50
;playercards:               defb 0,0,0,0,0 :endofplayercards ; LEFT NIBBLE SUIT, RIGHT NIBBLE NUMBER
;computercards:             defb 0,0,0,0,0 :endofcomputercards
;playerresult:              defb 0 ; VALUE OF HAND
;computerresult:            defb 0 ; VALUE OF HAND
;computerpairvalueresults:  defb 0,0 ; NUM CARDS, VALUE OF HAND
;computerpair2valueresults: defb 0,0 ; NUM CARDS, VALUE OF HAND
;playerpairvalueresults:    defb 0,0 ; NUM CARDS, VALUE OF HAND
;playerpair2valueresults:   defb 0,0 ; NUM CARDS, VALUE OF HAND
potstr  equ cartdataarea+20 ;defb "POT CONTAINS $",17,0,0,255
pot     equ potstr+15       ;defb 0,0 ; AMOUNT BETTED
cpuname equ potstr+18       ;RANDOM CPU NAME
cpucash equ cpuname+1       ;defb 0,0 ; AMOUNT OF MONEY CPU HAS TO SPEND
cpuraisestr equ cpucash+2

; ABOVE VARIABLES = 38 bytes

; WRITING TO C000 SHOULD BE OK AS LONG AS THE MAIN PROGRAM CODE DOES NOT USE THIS MEMORY
; OTHERWISE WE NEED TO MAKE SURE WE USE VARIABLES ALLOCATED BY THE MAIN CODE

; CARTRIDGE FUNCTIONS JUMP TABLE
romfunctiontable:
  jp newsaloongame
  
newsaloongame:
  ld hl,str_askplaypoker
  call askyesnoplayer
  jr nz,playthegame
ret
  
playthegame:
  ; COPY POT STR TO NORMAL MEMORY SO WE CAN USE STATUS BAR FUNCTION WITH ARGUMENTS
  ld hl,str_potcontains
  ld de,potstr
  ld bc,18
  ldir
  
  ; SET CPU NAME
  call genrandommanname
  ld (cpuname),a
  ; SET CPU CASH
  ld (cpucash),a

  ld hl,str_dealhand
  call statusbarprintparagraph
  call dealcards
  call drawcard1 ; DRAW PLAYER HAND
  call waitspace
  pokerloop:
  jp playerturn
  endplayerturn:
  jp cputurn  ; NEED TO MODIFY THIS SO THE LOOP STOPS WHEN THE GAME STOPS
  quitgame:
  ret
  
str_askplaypoker: defb "DO YOU WANT TO PLAY POKER?",255
str_dealhand:     defb "HERE ARE YOUR CARDS",255
str_menu:         defb "RAISE",10,"CALL",10,"FOLD",255
str_nomoney:      defb "YOU DON'T HAVE ENOUGH MONEY",255
str_potcontains:  defb "POT CONTAINS $",17,0,0,255
str_cpuraisestr:  defb 21,0," RAISES $20",255,255
str_cpucallstr:   defb 21,0," CALLS",255
str_cpufoldstr:   defb 21,0," FOLDS",255
str_cpuwinsstr:   defb 21,0," WINS THE POT",255
str_youcallstr:   defb "YOU CALL",255
str_youwin:       defb "YOU WIN THE POT",255

askyesnoplayer:
  call statusbarprintparagraph
  call checknokeyspressed ; PAUSE TO MAKE SURE PLAYER ISN'T HOLDING DOWN KEYS
  call waityesno
  cp "n"
ret

playerturn:
  ld hl,str_menu
  call statusbarprintparagraph
  ld a,3
  call waitoption_1_2_3_4_5ss
  cp 3
  jp z,clearmenu
  ld hl,menufunctions
  jp vectortablelaunchcode

menufunctions:
  defw raiseplayer        ; RAISE - A player who thinks he has a good hand (or who wants the other players to think he has a good hand) may increase the wager required to continue playing.
  defw callplayer         ; CALL  - Once a player has raised the stakes, each player must decide whether to raise the stakes again, to give in and fold his hand, or to call, which means to equal the amount wagered by the player who raised.
  defw foldplayer         ; FOLD  - A player who thinks his hand is not good enough to win and who does not want to wager the increased amount may lay down his cards. He cannot win the hand, but he also will not lose any more chips.
  ;defw askyesnoplayer    ; CHECK - If no one has increased the wager required to continue, a player may stand pat by checking, or passing on his option to bet.

cputurn:
  ld a,(cartdataarea+11)  ; SEE WHAT HAND WE HAVE - USE AS PROBABILITY OF FOLD
  ld b,a
  call randmax
  sub 3
  jp c,foldcpu
  sub 3
  jp c,callcpu
  jp foldcpu
  
cpufunctions:
  defw raisecpu
  defw callcpu
  defw foldcpu

callplayer:
  ld hl,str_youcallstr
  ld de,cpuraisestr
  ld bc,9
  ldir
  ld hl,cpuraisestr
  call copycpunametostr
  call statusbarprintparagraphnoscroll
  call waitspace
  jp endplayerturn

raiseplayer:
  ld hl,(pot)
  ld bc,20
  add hl,bc
  ld b,h
  ld c,l
  ld hl,(player_cash2)
  sbc hl,bc
  jr c,outofcashplayer
  ; ADD MONEY TO POT
  ld bc,20
  ld hl,(pot)
  add hl,bc
  ld (pot),hl
  ; DISPLAY POT
  call printpot
  call waitspace
  jp endplayerturn
  
printpot:
  ld hl,potstr
  jp statusbarprintparagraphnoscroll

outofcashplayer:
  ld hl,str_nomoney
  call statusbarprintparagraph
  jp pokerloop
  
outofcashcpu:
  jp foldcpu

raisecpu:
  ld hl,(pot)
  ld bc,20
  add hl,bc
  ld b,h
  ld c,l
  ld hl,(cpucash)
  sbc hl,bc
  jr c,outofcashcpu
  ; DISPLAY CPU RAISE
  ld hl,str_cpuraisestr
  ld de,cpuraisestr
  ld bc,14
  ldir
  
  ld hl,cpuraisestr
  call copycpunametostr
  call statusbarprintparagraphnoscroll
  ; ADD MONEY TO POT
  ld bc,20
  ld hl,(pot)
  add hl,bc
  ld (pot),hl
  ; DISPLAY POT
  call printpot
  call waitspace
  jp pokerloop

foldplayer:
  ; TAKE WINNINGS
  call printpot
  ld bc,(pot)
  ld hl,(cpucash)
  add hl,bc
  ld (cpucash),hl
  ld bc,0
  ld (pot),bc
  
  ; PRINT WINNER
  ld hl,str_cpuwinsstr
  ld de,cpuraisestr
  ld bc,16
  ldir
  ld hl,cpuraisestr
  call copycpunametostr
  call statusbarprintparagraphnoscroll
  call drawcard2 ; DRAW COMPUTER HAND
  call waitspace
  jp quitgame

callcpu:
  ld hl,str_cpucallstr
  ld de,cpuraisestr
  ld bc,9
  ldir
  ld hl,cpuraisestr
  call copycpunametostr
  call statusbarprintparagraphnoscroll
  call waitspace
  jp pokerloop

; INPUT
; HL = START OF STRING TO PRINT USING CPU NAME
; CPU NAME AT START OF STRING
copycpunametostr:
  inc hl            ; COPY CPU NAME
  ld a,(cpuname)
  ld (hl),a
  dec hl
ret

foldcpu:
  ld hl,str_cpufoldstr
  ld de,cpuraisestr
  ld bc,9
  ldir
  ld hl,cpuraisestr
  call copycpunametostr
  call statusbarprintparagraphnoscroll
  
  ; TAKE WINNINGS
  call printpot
  ld bc,(pot)
  ld hl,(player_cash2)
  add hl,bc
  ld (player_cash2),hl
  ld bc,0
  ld (pot),bc
  
  ; PRINT WINNER
  ld hl,str_youwin
  call statusbarprintparagraphnoscroll
  call updatestatusbarmoney ; SHOW WINNINGS
  call drawcard2            ; DRAW COMPUTER HAND
  call waitspace
  jp quitgame

; HANDS
; -----

; High card
;   If no combination can be made, then a player’s hand is valued at the highest single card. 
;   If two players have the same high card, then the second highest card would break the tie.
;   Example: 5♣ 8♦ 10♠ Q♥ A♠
; One Pair. 
;   A pair is formed when you have two of any of the same cards.
;   Example: 9♠ 9♦ 5♣ 8♣ K♥
; Two Pairs.
;   When more than one player has two pairs, the player with the highest pair wins.
;   Example: 9♠ 9♦ 5♣ 5♥ 8♥
; Three of a Kind.
;   Example: 9♠ 9♦ 9♥ 5♣ 8♣
; Straight. 
;   A straight is a five-card hand consisting of a running sequence of cards, regardless of suit. 
;   If two players have straights, the straight of the higher card wins.
;   Example: 9♠ 10♠ J♦ Q♥ K♦
; -Flush. 
;   When all five cards in a hand are of the same suit, it is a flush. 
;   If two players have a flush, the person with the highest card in that suit wins.
;   Example: 9♠ 5♠ Q♠ K♠ 7♠
; Full House.
;   When a player has three-of-a-kind and a pair in the same hand, it is called a Full House.
;   Example: 9♠ 9♦ 9♥ 5♣ 5♥
; Four of a Kind. 
;   If you are lucky enough to have all four of a given number, then you have a very powerful hand.
;   Example: 9♠ 9♦ 9♥ 9♣ 5♣
; Straight Flush. 
;   Even rarer than four of a kind, a straight flush is made up of five consecutive cards, all from the same suit.
;   Example: 9♠ 10♠ J♠ Q♠ K♠
; -Royal Flush. 
;   The best hand of them all is this famous combination, formed by a Straight Flush that runs to the Ace, 
;   making it unbeatable. Odds of being dealt this hand can be as high as 1 in 650,000 deals.
;   Example: 10♥ J♥ Q♥ K♥ A♥

; CHECK FLUSH
; INPUTS 
; HL = HAND TO CHECK
; OUTPUTS
; A = 1 OR 0
; 0 = NO FLUSH
; 1 = FLUSH
checkflush:
  push hl
  ld a,(hl)
  and %11110000 ; ERASE NUMBERS
  ld c,a
  ld b,4
  checkflushloop:
    inc hl
    ld a,(hl)
	and %11110000 ; ERASE NUMBERS
	cp c
	jr nz,returnfalse
  djnz checkflushloop
  ld a,(hl)
  and %00001111 ; ERASE SUIT
  ld a,1        ; NORMAL FLUSH
  pop hl
ret
returnfalse:
  pop hl
  xor a
ret

; CHECK STRAIGHT
; INPUTS 
; HL = HAND TO CHECK
; OUTPUTS
; A = 1 OR 0
; 0 = NO STRAIGHT
; 1 = STRAIGHT
checkstraight:
  push hl
  ld a,(hl)
  and %00001111 ; ERASE SUIT
  ld c,a
  ld b,4
  checkstraightloop:
    inc hl
    ld a,(hl)
	and %00001111 ; ERASE SUIT
	inc c
	cp c
	jr nz,returnfalse
  djnz checkstraightloop
  ld a,1        ; NORMAL STRAIGHT
  pop hl
ret

; CHECK PAIRS
; INPUTS 
; HL = HAND TO CHECK
; OUTPUTS
; D, E = NUMBER OF CARDS WITH SAME RANK - FIRST AND SECOND PAIR
checktwothreefourofakind:
  push hl
  ld a,(hl)
  and %00001111 ; ERASE SUIT
  ld c,a
  ld b,0  ; RECORD VALUE OF FIRST PAIR
  ld d,0  ; RECORD HOW MANY CARDS ARE SAME NUMBER - PAIR 1,2
  ld e,0
  call checktwothreefourofakindloop
  call checktwothreefourofakindloop
  call checktwothreefourofakindloop
  call checktwothreefourofakindloop
  pop hl
ret
checktwothreefourofakindloop:
  inc hl
  ld a,(hl)
  and %00001111 ; ERASE SUIT
  cp c
  jr nz,movetonexttwothreefourofakind
  ; WE HAVE A MATCH
  ; CHECK IF WE HAVE A PAIR ALREADY IN d, IF SO INC e INSTEAD FOR SECOND PAIR
  ld a,b
  or a    ; IF WE HAVE NO VALUE IN B
  jr z,incrementfirstpair
  ld a,c  ; IF CARD IS SAME VALUE AS B
  cp b
  jr z,incrementfirstpair
  ; INCREMENT SECOND PAIR
  inc e
  ld a,c
  ld (cartdataarea+14),a ; STORE SECOND PAIR VALUE
  ld a,e
  ld (cartdataarea+15),a ; STORE SECOND PAIR NUMBERS
  movetonexttwothreefourofakind:
  ld a,(hl)
  and %00001111 ; ERASE SUIT
  ld c,a
ret

; RECORD THAT WE HAVE ANOTHER CARD THE SAME - FIRST PAIR
incrementfirstpair:
  ld b,c                 ; RECORD VALUE OF FIRST PAIR
  inc d
  ld a,c
  ld (cartdataarea+12),a ; STORE PAIR VALUE
  ld a,d
  ld (cartdataarea+13),a ; STORE PAIR NUMBERS
  jr movetonexttwothreefourofakind


; SORT HAND BY NUMBER LEFT TO RIGHT
; INPUTS
; HL = HAND TO SORT
sorthand:
  push hl
  ld b,4 ; 5 CARDS TO SORT
  sorthandloop:
    ld a,(hl)
	and %00001111 ; ERASE SUIT
	ld c,a
    inc hl
    ld a,(hl)
    and %00001111 ; ERASE SUIT
  
    sub c
	jr c,switchvals ; MAKE LARGER VALUE ON RIGHT
  djnz sorthandloop
  pop hl
ret

switchvals:
  ld c,(hl)
  dec hl
  ld a,(hl)
  ld (hl),c
  inc hl
  ld (hl),a
  pop hl
  jr sorthand

; INPUT
; HL = START OF PLAYER / COMPUTER HAND
; OUTPUTS
; A = HAND TYPE
checkhand:
  push hl
  call checkflush
  pop hl
  cp 1
  jp z,checkstraightflush
  call checkstraight
  cp 1
  jp z,displaystraight
  call checktwothreefourofakind
  jp displaytwothreefourofakind

; INPUT
; A = HAND
; 0 = NO COMBINATION FOUND
displayhand:
  ld (cartdataarea+10),a ; STORE RESULT OF HAND FOR COMPARISON
  or a
  ret z
  ld hl,displayhandtable
  call vectorlookuphl
  ex de,hl
  ld hl,youhavea
  jp statusbarprintparagraphnoscroll

; INPUT
; A = HAND
; 0 = NO COMBINATION FOUND
displaycpuhand:
  ld (cartdataarea+11),a ; STORE RESULT OF HAND FOR COMPARISON
  or a
  ret z
  ld hl,displayhandtable
  call vectorlookuphl
  ex de,hl
  ld hl,computerhasa
  jp statusbarprintparagraphnoscroll

determinewinner:
  ld bc,(cartdataarea+10)
  ld a,b
  sub c ; COMPUTER HAS HIGHER HAND
  jr c,displayplayerwins
  
  ;ld (cartdataarea+0),a
  or a  ; PLAYER AND COMPUTER HAVE SAME HAND, CHECK WHICH HAS HIGHER CARD
  jr z,checkdraw
  displaycomputerwins:
  ld hl,computerwins
  jp statusbarprintparagraphnoscroll
  
  displayplayerwins:
  ld hl,playerwins
  jp statusbarprintparagraphnoscroll
  
playerwins:        defb "YOU WIN",255
computerwins:      defb "CPU WINS",255
playerhigherpair:  defb "YOU HAVE HIGHER PAIR",255
cpuhigherpair:     defb "CPU HAS HIGHER PAIR",255
itsadraw:          defb "IT'S A DRAW",255
;errol:             defb "ERROL",255
;checkinghighcards: defb "CHECKING HIGH CARDS",255

; IF BOTH PLAYERS HAVE SAME HAND, CHECK WHO HAS HIGHEST PAIR, ETC
checkdraw:
  ld a,(cartdataarea+10)
  cp 1
  jr z,checkhighcardpairthreefourofkind
  cp 2
  jr z,checkhighcardtwopairs
  cp 3
  jr z,checkhighcardpairthreefourofkind
  jr checkhighcardnosuites
  ;ld hl,notsurewhowins
  ;jp statusbarprintparagraphnoscroll

; -------------------------------------------------------
; WE HAVE A PAIR, CHECK WHICH PAIR IS HIGHER

checkhighcardtwopairs:
  ; CHECK WHICH PLAYER HAS HIGHER PAIRS
  ; IF BOTH THE SAME, CHECK UNPAIRED CARDS
  ; IF STILL BOTH THE SAME, SPLIT POT

  ld a,(cartdataarea+12)      ; LOAD CPU PAIRS IN A
  ld b,a
  ld a,(cartdataarea+16)      ; SUB PLAYER PAIRS
  sub b
  jp c,displaycomputerwins
  or a
  jr z,checksecondpair        ; NO WINNER, CHECK SECOND HIGH CARDS
  jp displayplayerwins

checksecondpair:
  ;ld hl,errol
  ;call statusbarprintparagraphnoscroll
  ld a,(cartdataarea+14)      ; LOAD CPU PAIRS IN A
  ld b,a
  ld a,(cartdataarea+18)      ; SUB PLAYER PAIRS
  sub b
  jp c,displaycomputerwins
  or a
  jr z,checkhighcardnosuites  ; NO WINNER, BOTH PAIRS SAME, CHECK HIGH CARDS
  jp displayplayerwins
  
checkhighcardpairthreefourofkind:
  ; CHECK WHICH PLAYER HAS HIGHER PAIR, OR THREE OR FOUR OF A KIND
  ; IF BOTH THE SAME, CHECK UNPAIRED CARDS
  ; IF STILL BOTH THE SAME, SPLIT POT
  
  ld a,(cartdataarea+12)      ; LOAD CPU PAIRS IN A
  ld b,a
  ld a,(cartdataarea+16)      ; SUB PLAYER PAIRS
  sub b
  jp c,displaycomputerwins
  or a
  jr z,checkhighcardnosuites  ; NO WINNER, CHECK HIGH CARDS
  jp displayplayerwins

; -------------------------------------------------------
; NO WINNING COMBINATION, CHECK WHO HAS HIGH CARD

checkhighcardnosuites:
  ;ld hl,checkinghighcards
  ;call statusbarprintparagraphnoscroll
  ld b,5   ; TIMES TO DECREMENT - DON'T GO BEYOND CART DATA AREA
  ld hl,cartdataarea+4
  ld de,cartdataarea+9
checkhighcard2nosuites:
  ld a,b
  or a      ; WE CHECKED ALL CARDS, IS GENUINE DRAW - SPLIT POT
  jr z,isadraw
  
  ld a,(hl)     ; LOAD PLAYER HIGH CARD
  and %00001111 ; ERASE SUIT
  ld c,a
  ld a,(de)     ; LOAD CPU HIGH CARD
  and %00001111 ; ERASE SUIT
  sub c
  jp c,displayplayerwins
  or a
  jr z,isadrawcheckprevhighcard
  jp displaycomputerwins

isadrawcheckprevhighcard:
  dec b
  dec hl
  dec de
  jr checkhighcard2nosuites
  
isadraw:
  ld hl,itsadraw
  jp statusbarprintparagraphnoscroll
  
  
; -------------------------------------------------------

displayhandtable:
  defw highcard
  defw onepair
  defw twopairs
  defw threeofakind
  defw straight
  defw flush
  defw fullhouse
  defw fourofakind
  defw straightflush
  defw royalflush
  
youhavea:      defb "YOU HAVE",11,255
computerhasa:  defb "CPU HAS",11,255
highcard:      defb "A HIGH CARD",255
onepair:       defb "ONE PAIR",255
twopairs:      defb "TWO PAIRS",255
threeofakind:  defb "THREE OF A KIND",255
straight:      defb "A STRAIGHT",255
flush:         defb "A FLUSH",255
fullhouse:     defb "A FULL HOUSE",255
fourofakind:   defb "FOUR OF A KIND",255
straightflush: defb "A STRAIGHT FLUSH",255
royalflush:    defb "A ROYAL FLUSH",255

displaypair:
  ld a,1
ret
displaythreeofakind:
  ld a,3
ret
displaystraight:
  ld a,4
ret
displayflush:
  ld a,5
ret
displayfullhouse:
  ld a,6
ret
displayfourofakind:
  ld a,7
ret
displaystraightflush:
  ld a,8
ret
displayroyalflush:
  ld a,9
ret
displaytwothreefourofakind:
  ld a,d
  or a
  ret z ; WE HAVE NO MATCHING CARDS
  ld a,e
  or a
  jr nz,displaytwopairs ; WE HAVE TWO PAIRS
  ld a,d
  inc a ; INCREMENT TO INCLUDE FIRST CARD IN KIND
  cp 2 ; WE HAVE A PAIR
  jr z,displaypair;threeofakind
  cp 3 ; WE HAVE THREE OF A KIND
  jr z,displaythreeofakind
  cp 4  ; WE HAVE FOUR OF A KIND!
  jr z,displayfourofakind
ret


displaytwopairs:
  ; CHECK FOR FULL HOUSE
  ld a,e
  inc a ; INCREMENT TO INCLUDE FIRST CARD IN KIND
  cp 3
  jr z,displayfullhouse
  cp 2
  jr z,checkdisplayfullhouse
  ld a,2
ret
checkdisplayfullhouse:
  ld a,d
  inc a ; INCREMENT TO INCLUDE FIRST CARD IN KIND
  cp 3
  jr z,displayfullhouse
  ld a,2
ret


; MOVE BASED ON DIRECTION JUMP TABLE
; VECTOR TABLE LAUNCH CODE
; INPUTS 
; A = ID NUMBER
; HL = LOOKUP TABLE
vectortablelaunchcode:
  call vectorlookuphl
  jp (hl)     ; JUMP TO VECTOR TABLE FUNCTION



; DEAL CARDS
; -------------------------------------

; INPUT
; HL = TILE BUFFER TO CLEAR
; BC = SIZE OF DATA TO CLEAR
clearmem:
  push hl
  dec bc
  push hl
  pop de
  inc de
  ld (hl),0
  ldir
  pop hl
ret

dealcards:
  ; ERASE HANDS
  ld hl,cartdataarea
  ld bc,20 ; 0DD0 CARD AREA
  call clearmem
  
  ; GET 5 RANDOM CARDS FOR PLAYER
  ; -----------------------------
  
  ld hl,cartdataarea
  ld (hl),&35
  inc hl
  ld (hl),&25
  inc hl
  ld (hl),&1B
  inc hl
  ld (hl),&1B
  inc hl
  ld (hl),&2B
  
  ;ld hl,cartdataarea
  ;ld b,5
  ;call getcardloop
  ld hl,cartdataarea   ; SORT PLAYER HAND IN NUMERICAL ORDER
  call sorthand
  call checkhand
  call displayhand
  
  ; MOVE PLAYER RESULTS TO NEW MEMORY PLACE FOR COMPARISON AGAINST COMPUTER
  ld de,cartdataarea+16
  ld hl,cartdataarea+12
  ld bc,4
  ldir
   
  ; GENERATE COMPUTER HAND
  ; ----------------------
   
  ; GET 5 RANDOM CARDS FOR COMPUTER
  ld hl,cartdataarea+5
  ld (hl),&35
  inc hl
  ld (hl),&25
  inc hl
  ld (hl),&1A
  inc hl
  ld (hl),&1B
  inc hl
  ld (hl),&1B
  ;ld hl,cartdataarea+5
  ;ld b,5
  ;call getcardloop
  
  ld hl,cartdataarea+5 ; SORT COMPUTER HAND IN NUMERICAL ORDER
  call sorthand
  call checkhand
  ;call displaycpuhand
  jp determinewinner

; INPUT
; HL = CARD HAND
checkstraightflush:
  push hl
  call checkstraight
  pop hl
  cp 1
  jp z,checkroyalflush
  jp displayflush

checkroyalflush:
  push hl
  inc hl
  inc hl
  inc hl
  inc hl
  ld a,(hl)
  pop hl
  cp 12
  jp z,displayroyalflush
  jp displaystraightflush

; INPUT
; HL = START OF CARD HAND MEMORY LOCATION
; B  = NUMBER OF CARDS TO PICK
getcardloop:
  push hl
  push bc
  call generatecard
  pop bc
  pop hl
  ld (hl),a
  inc hl
  djnz getcardloop
ret

; GENERATE CARD
; CHECK CARD IS NOT TAKEN ALREADY
; IF SO, REGENERATE
generatecard: 
  ld b,4  ; GET RANDOM SUIT
  call randmax
  rlca
  rlca
  rlca
  rlca
  ld c,a
  ld b,13 ; GET RANDOM NUMBER
  call randmax
  or c   ; MERGE WITH SUIT 
  ld d,a  ; BACKUP A IN D

  ; FIND IF CARD TAKEN ALREADY
  ld hl,cartdataarea+9
  ld bc,10
  cpdr                     
  jr z,generatecard  ; WE FOUND DUPLICATE! REGENERATE
  
  ld a,d              ; RETURN GENERATED CARD
ret

; DRAW CARD ON SCREEN
; -------------------

screenadr equ &8000

cardnumberstable:
  defw two
  defw three
  defw four
  defw five
  defw six
  defw seven
  defw eight
  defw nine
  defw ten
  defw jack
  defw queen
  defw king
  defw ace
	  
two:    defb "2",255
three:  defb "3",255
four:   defb "4",255
five:   defb "5",255
six:    defb "6",255
seven:  defb "7",255
eight:  defb "8",255
nine:   defb "9",255
ten:    defb "10",255
jack:   defb "J",255
queen:  defb "Q",255
king:   defb "K",255
ace:    defb "A",255

drawcard1:
  ld hl,screenadr+407
  ld a,(cartdataarea)
  call drawcard
  ld hl,screenadr+421
  ld a,(cartdataarea+1)
  call drawcard
  ld hl,screenadr+435
  ld a,(cartdataarea+2)
  call drawcard
  ld hl,screenadr+449
  ld a,(cartdataarea+3)
  call drawcard
  ld hl,screenadr+463
  ld a,(cartdataarea+4)
  jp drawcard

drawcard2:
  ld hl,screenadr+807+80
  ld a,(cartdataarea+5)
  call drawcard
  ld hl,screenadr+821+80
  ld a,(cartdataarea+6)
  call drawcard
  ld hl,screenadr+835+80
  ld a,(cartdataarea+7)
  call drawcard
  ld hl,screenadr+849+80
  ld a,(cartdataarea+8)
  call drawcard
  ld hl,screenadr+863+80
  ld a,(cartdataarea+9)
;  jp drawcard
  
; INPUTS
; HL = SCREEN LOCATION
; A  = SUIT/NUMBER
drawcard:
  push hl
  push af
  ld a,&0C
  call DrawHorizLineCard
  ld a,&C0 ; WHITE LINE
  ld b,40
  drawcardloop:
    push bc
    call DrawHorizLineCard
	pop bc
  djnz drawcardloop
  ld a,&0C
  call DrawHorizLineCard
  pop af
  
  pop hl
  ld d,h ; STORE SCREEN LOC IN DE
  ld e,l
  push hl
  
  ; DRAW SUIT / NUMBERS
  push af
  and %00001111 ; GET NUMBER
  ld hl,cardnumberstable
  call vectorlookuphl
  
  ; DRAW NUMBER TO CARD
  ex de,hl             ; GET TEXT IN DE, SCR ADR IN HL
  call scr_next_line_hl
  call scr_next_line_hl
  inc hl
  call gra_wr_string2
  
  pop af
  
  ; DRAW SUIT
  and %11110000 ; GET SUIT
  rrca
  rrca
  rrca
  rrca
  ld hl,suitstable
  call vectorlookuphl
  ex de,hl              ; GET SPRITE DATA IN DE
  
  pop hl
  
  ; DRAW IMAGE ON CARD
  call scr_next_line_hl
  call scr_next_line_hl
  call scr_next_line_hl
  call scr_next_line_hl
  ld bc,&50
  add hl,bc
  inc hl
  inc hl
  inc hl
  call drawsprite
ret

vectorlookuphl:
  push bc
  ;rlca ; DOES NOT WORK OVER TABLE LENGTH > 128
  ld b,0
  ld c,a
  add hl,bc
  add hl,bc
  ld a,(hl)
  inc hl
  ld h,(hl)
  ld l,a
  pop bc
ret

; GRAPHICS FUNCTIONS
; ------------------

scr_next_line_hl:
  ld a,h
  add &08
  ld h,a

  ; CHECK IF WE WENT PAST END OF SCREEN
  sub &c0   ; IF USING &8000 FOR SCREEN MEM
  ret c

  ld bc,&C050
  add hl,bc
ret

; DRAW A LINE THE WIDTH OF THE CARD
; INPUTS
; HL = SCREEN MEMORY LOCATION
; A = LINE COLOUR
; A PRESERVED
DrawHorizLineCard:
  push af
  push hl
  ld (hl),a ; LINE COL
  push hl ; COPY HL TO DE
  pop de 
  inc de
  call ldicard
  pop hl
  call scr_next_line_hl
  pop af
ret

; DRAW A LINE THE WIDTH OF THE CARD
ldicard:
  ldi
  ldi
  ldi
  ldi
  ldi
  ldi
  ldi
  ldi
  ldi
ret

; INPUTS
; HL = SCREEN ADDR
; DE = SPRITE ADDR
drawsprite:
  ld b,16 ; 16 ROWS
  drawspriteloop:
	push bc
    push hl
    ex de,hl
	ldi
	ldi
	ldi
	ldi
	ex de,hl
	pop hl
	call scr_next_line_hl
    pop bc
  djnz drawspriteloop
ret
  
; IMAGES
; ---------------------------------

suitstable:
  defw cardclubimg
  defw carddiamondimg
  defw cardheartimg
  defw cardspadeimg

cardclubimg:
        DB      #C0, #C0, #C0, #C0
        DB      #C0, #C0, #C0, #C0
        DB      #C0, #95, #6A, #C0
        DB      #C0, #2E, #1D, #C0
        DB      #C0, #0C, #0C, #C0
        DB      #C0, #2E, #1D, #C0
        DB      #95, #84, #48, #6A
        DB      #2E, #2E, #1D, #1D
		DB      #0C, #0C, #0C, #0C
        DB      #2E, #2E, #1D, #1D
        DB      #95, #84, #48, #6A
        DB      #C0, #84, #48, #C0
        DB      #C0, #2E, #1D, #C0
        DB      #C0, #C0, #C0, #C0
        DB      #C0, #C0, #C0, #C0
		
carddiamondimg:
	    DB      #C0, #C0, #C0, #C0
        DB      #C0, #C0, #C0, #C0
        DB      #C0, #D4, #E8, #C0
        DB      #C0, #90, #60, #C0
        DB      #C0, #B8, #74, #C0
        DB      #C0, #30, #30, #C0
        DB      #D4, #30, #30, #E8
        DB      #90, #30, #30, #60
        DB      #D4, #30, #30, #E8
        DB      #C0, #30, #30, #C0
        DB      #C0, #B8, #74, #C0
        DB      #C0, #90, #60, #C0
        DB      #C0, #D4, #E8, #C0
        DB      #C0, #C0, #C0, #C0
        DB      #C0, #C0, #C0, #C0
        DB      #C0, #C0, #C0, #C0
		
cardheartimg:
	    DB      #C0, #C0, #C0, #C0
        DB      #C0, #C0, #C0, #C0
        DB      #D4, #E8, #D4, #E8
        DB      #90, #60, #90, #60
        DB      #B8, #74, #B8, #74
        DB      #30, #30, #30, #30
        DB      #B8, #30, #30, #74
        DB      #90, #30, #30, #60
        DB      #90, #30, #30, #60
        DB      #D4, #30, #30, #E8
        DB      #C0, #30, #30, #C0
        DB      #C0, #B8, #74, #C0
        DB      #C0, #90, #60, #C0
        DB      #C0, #D4, #E8, #C0
        DB      #C0, #C0, #C0, #C0
        DB      #C0, #C0, #C0, #C0
		
cardspadeimg:
	    DB      #C0, #C0, #C0, #C0
        DB      #C0, #C0, #C0, #C0
        DB      #C0, #95, #6A, #C0
        DB      #C0, #84, #48, #C0
        DB      #C0, #2E, #1D, #C0
        DB      #C0, #0C, #0C, #C0
        DB      #95, #0C, #0C, #6A
        DB      #84, #0C, #0C, #48
        DB      #2E, #0C, #0C, #1D
		DB      #0C, #0C, #0C, #0C
        DB      #2E, #2E, #1D, #1D
        DB      #95, #84, #48, #6A
        DB      #C0, #84, #48, #C0
        DB      #C0, #2E, #1D, #C0
        DB      #C0, #C0, #C0, #C0
        DB      #C0, #C0, #C0, #C0