; ADDITIONAL ROUTINES FOR PLUS CART

; JUMP TABLE FOR FUNCTIONS AT START OF ROM
; IN ORDER TO MAKE MAIN PROGRAM FUNCTIONS CALLABLE FROM CART,
; WE NEED A JUMP TABLE IN RAM

org &C000 ; START OF ROM ADDRESS IN MEMORY

; = &0DAE - JUMP TABLE FUNCTIONS
statusbarprintparagraph         equ &0C00+430 ; 0DAE
checknokeyspressed              equ statusbarprintparagraph+3
waityesno                       equ checknokeyspressed+3
randmax                         equ waityesno+3
gra_wr_string2                  equ randmax+3
waitoption_1_2_3_4_5ss          equ gra_wr_string2+3
makewanted_cf                   equ waitoption_1_2_3_4_5ss+3
statusbarprintparagraphnoscroll equ makewanted_cf+3
updatestatusbarmoney            equ statusbarprintparagraphnoscroll+3
waitspace                       equ updatestatusbarmoney+3
;vectorlookupsingle              equ waitspace+3

; FIXED POINTERS TO GAME DATA
tiletabley						equ &0A00
gamemap2						equ tiletabley+256        ; 10x10 = 100 BYTES
scr_addr_table					equ gamemap2+256          ; SIZE 200 * 2
player_cash2					equ scr_addr_table+400    ; SIZE 2 BYTES

; PLAYER CARDS / COMPUTER CARDS
; -----------------------------
; 
; CARDS - A RANDOM NUMBER BETWEEN 0 AND 51 (HEART, CLUB, DIAMOND, SPADE)
; AFTER CARDS HAVE BEEN DEALT, ARRANGE IN SUIT ORDER FOR CALCULATING WHICH HAND WINS

;              A,2,3,4,5,6,7,8,9,10,J,Q,K
cartdataarea equ &0DD0 
;playercards:               defb 0,0,0,0,0 :endofplayercards ; LEFT NIBBLE SUIT, RIGHT NIBBLE NUMBER
playercards                 equ cartdataarea
cardsdealt                  equ cartdataarea+5 ; defb 0
winningsselected            equ cartdataarea+6 ; defb 0

; ABOVE VARIABLES = 6 bytes

; WRITING TO C000 SHOULD BE OK AS LONG AS THE MAIN PROGRAM CODE DOES NOT USE THIS MEMORY
; OTHERWISE WE NEED TO MAKE SURE WE USE VARIABLES ALLOCATED BY THE MAIN CODE

; CARTRIDGE FUNCTIONS JUMP TABLE
romfunctiontable:
  jp newsaloongame
  
newsaloongame:
  ld hl,str_askplayhigherlower
  call askyesnoplayer
  jr nz,playthegame
ret
  
playthegame:
  ; ERASE HANDS
  ld hl,cartdataarea
  ld bc,20 ; 0DD0 CARD AREA
  call clearmem

  ; ASK STAKES
  ld hl,str_askstakes
  call statusbarprintparagraph
  ld a,3 ; CHECK 1-3 KEYPRESS
  call waitoption_1_2_3_4_5ss
  ld hl,gamewinnings
  call vectorlookupsingle
  ld (winningsselected),a ; SAVE PLAYER'S CHOICE
  
  ; MAIN GAME LOOP
  call dealcards
  
  ; DRAW FIRST CARD
  ld hl,drawcardtable
  ld a,(cardsdealt)
  call vectortablelaunchcode
  
  ; ASK HIGHER LOWER
  call playerturn
    
  ; MOVE TO NEXT CARD
  ld a,(cardsdealt)
  cp 255
  ret z
  inc a
  ld (cardsdealt),a
  
  call playerturn
  ; MOVE TO NEXT CARD
  ld a,(cardsdealt)
  cp 255
  ret z
  inc a
  ld (cardsdealt),a
  
  call playerturn
  ; MOVE TO NEXT CARD
  ld a,(cardsdealt)
  cp 255
  ret z
  inc a
  ld (cardsdealt),a
  
  call playerturn
  ; MOVE TO NEXT CARD
  ld a,(cardsdealt)
  cp 255
  ret z
  
  ; WE WON!
gamewin:
  ld hl,str_playerwins
  call statusbarprintparagraph
  ld b,0
  ld a,(winningsselected) ;call getwinnings
  ld c,a
  ld hl,(player_cash2)
  add hl,bc
  jr printwinnings
gamelose:
  ; RECORD THAT WE LOST GAME
  ld a,255
  ld (cardsdealt),a
  
  ld hl,str_playerloses
  call statusbarprintparagraph
  ld b,0
  ld a,(winningsselected) ;call getwinnings
  ld c,a
  ld hl,(player_cash2)
  sbc hl,bc
  jr c,outofcash
  printwinnings:
  ld (player_cash2),hl
  call updatestatusbarmoney
  call checknokeyspressed ; PAUSE TO MAKE SURE PLAYER ISN'T HOLDING DOWN KEYS
  jp waitspace
  
callhigher:
  call getcardvaluesinba
  sub b
  jr c,gamelose
ret
calllower:
  call getcardvaluesinba
  sub b
  jr nc,gamelose
ret  

outofcash:
  ld bc,0
  ld (player_cash2),bc
  call updatestatusbarmoney
  ld hl,str_outofcash
  call statusbarprintparagraphnoscroll
  ; INCREASE WANTED LEVEL
  jp makewanted_cf
 
drawcardtable:
  defw drawcard1
  defw drawcard2
  defw drawcard3
  defw drawcard4
  defw drawcard5
 
gamewinnings:
  defb 5,10,20
  
;getwinnings
;  ld a,(winningsselected)
;  ld hl,gamewinnings
;  call vectorlookupsingle
;  ld b,0
;  ld c,a
;ret
  
vectorlookupsingle:
  push bc
  ld b,0
  ld c,a
  add hl,bc
  ld a,(hl)
  pop bc
ret
  
str_askplayhigherlower: defb "DO YOU WANT TO PLAY HIGHER OR LOWER?",255
str_askstakes:          defb "$5",10,"$10",10,"$20",10,"WHAT ARE YOUR STAKES?",255
str_menu:               defb "HIGHER",10,"LOWER",255
str_outofcash:          defb "NO MONEY? MAYBE THE JAILOR CAN MAKE YOU PAY!",255
str_playerwins:         defb "YOU WIN",255
str_playerloses:        defb "YOU LOSE",255
str_itsadraw:           defb "IT'S A DRAW",255

askyesnoplayer:
  call statusbarprintparagraph
  call checknokeyspressed ; PAUSE TO MAKE SURE PLAYER ISN'T HOLDING DOWN KEYS
  call waityesno
  cp "n"
ret

playerturn: 
  ; ASK HIGHER OR LOWER
  ld hl,str_menu
  call statusbarprintparagraph
  ld a,2
  call waitoption_1_2_3_4_5ss
  
  push af
  ; DRAW NEW CARD
  ld hl,drawcardtable
  ld a,(cardsdealt)
  inc a
  call vectortablelaunchcode
  pop af
  
  ld hl,menufunctions
  jp vectortablelaunchcode

menufunctions:
  defw callhigher        
  defw calllower        

; OUTPUTS
; CURRENT CARD VALUE IN B
; NEW CARD VALUE IN A
getcardvaluesinba:
  ld a,(cardsdealt)
  ld b,0
  ld c,a
  ld hl,playercards
  add hl,bc
  ld a,(hl) ; GET CURRENT CARD - LEFT NIBBLE SUIT, RIGHT NIBBLE NUMBER
  and %00001111 ; GET NUMBER
  ld b,a
  inc hl
  ld a,(hl) ; GET CURRENT CARD - LEFT NIBBLE SUIT, RIGHT NIBBLE NUMBER
  and %00001111 ; GET NUMBER
ret


 
; -------------------------------------------------------

; MOVE BASED ON DIRECTION JUMP TABLE
; VECTOR TABLE LAUNCH CODE
; INPUTS 
; A = ID NUMBER
; HL = LOOKUP TABLE
vectortablelaunchcode:
  call vectorlookuphl
  jp (hl)     ; JUMP TO VECTOR TABLE FUNCTION



; DEAL CARDS
; -------------------------------------

; INPUT
; HL = TILE BUFFER TO CLEAR
; BC = SIZE OF DATA TO CLEAR
clearmem:
  push hl
  dec bc
  push hl
  pop de
  inc de
  ld (hl),0
  ldir
  pop hl
ret

dealcards:
 
  ; GET 5 RANDOM CARDS FOR PLAYER
  ; -----------------------------
  
  ;ld hl,cartdataarea
  ;ld (hl),&35
  ;inc hl
  ;ld (hl),&25
  ;inc hl
  ;ld (hl),&1B
  ;inc hl
  ;ld (hl),&1B
  ;inc hl
  ;ld (hl),&2B
  
  ld hl,cartdataarea
  ld b,5
  jp getcardloop
  ;ld hl,cartdataarea   ; SORT PLAYER HAND IN NUMERICAL ORDER
  ;call checkhand
  ;call displayhand
;ret

; INPUT
; HL = START OF CARD HAND MEMORY LOCATION
; B  = NUMBER OF CARDS TO PICK
getcardloop:
  push hl
  push bc
  call generatecard
  pop bc
  pop hl
  ld (hl),a
  inc hl
  djnz getcardloop
ret

; GENERATE CARD
; CHECK CARD IS NOT TAKEN ALREADY
; IF SO, REGENERATE
generatecard: 
  ld b,4  ; GET RANDOM SUIT
  call randmax
  rlca
  rlca
  rlca
  rlca
  ld c,a
  ld b,13 ; GET RANDOM NUMBER
  call randmax
  or c   ; MERGE WITH SUIT 
  ld d,a  ; BACKUP A IN D

  ; FIND IF CARD TAKEN ALREADY
  ld hl,cartdataarea+9
  ld bc,10
  cpdr                     
  jr z,generatecard  ; WE FOUND DUPLICATE! REGENERATE
  
  ld a,d              ; RETURN GENERATED CARD
ret

; DRAW CARD ON SCREEN
; -------------------

screenadr equ &8000

cardnumberstable:
  defw two
  defw three
  defw four
  defw five
  defw six
  defw seven
  defw eight
  defw nine
  defw ten
  defw jack
  defw queen
  defw king
  defw ace
	  
two:    defb "2",255
three:  defb "3",255
four:   defb "4",255
five:   defb "5",255
six:    defb "6",255
seven:  defb "7",255
eight:  defb "8",255
nine:   defb "9",255
ten:    defb "10",255
jack:   defb "J",255
queen:  defb "Q",255
king:   defb "K",255
ace:    defb "A",255

drawcard1:
  ld hl,screenadr+407
  ld a,(cartdataarea)
  jp drawcard
drawcard2:
  ld hl,screenadr+421
  ld a,(cartdataarea+1)
  jp drawcard
drawcard3:
  ld hl,screenadr+435
  ld a,(cartdataarea+2)
  jp drawcard
drawcard4:
  ld hl,screenadr+449
  ld a,(cartdataarea+3)
  jp drawcard
drawcard5:
  ld hl,screenadr+463
  ld a,(cartdataarea+4)
  jp drawcard

; INPUTS
; HL = SCREEN LOCATION
; A  = SUIT/NUMBER
drawcard:
  push hl
  push af
  ld a,&0C
  call DrawHorizLineCard
  ld a,&C0 ; WHITE LINE
  ld b,40
  drawcardloop:
    push bc
    call DrawHorizLineCard
	pop bc
  djnz drawcardloop
  ld a,&0C
  call DrawHorizLineCard
  pop af
  
  pop hl
  ld d,h ; STORE SCREEN LOC IN DE
  ld e,l
  push hl
  
  ; DRAW SUIT / NUMBERS
  push af
  and %00001111 ; GET NUMBER
  ld hl,cardnumberstable
  call vectorlookuphl
  
  ; DRAW NUMBER TO CARD
  ex de,hl             ; GET TEXT IN DE, SCR ADR IN HL
  call scr_next_line_hl
  call scr_next_line_hl
  inc hl
  call gra_wr_string2
  
  pop af
  
  ; DRAW SUIT
  and %11110000 ; GET SUIT
  rrca
  rrca
  rrca
  rrca
  ld hl,suitstable
  call vectorlookuphl
  ex de,hl              ; GET SPRITE DATA IN DE
  
  pop hl
  
  ; DRAW IMAGE ON CARD
  call scr_next_line_hl
  call scr_next_line_hl
  call scr_next_line_hl
  call scr_next_line_hl
  ld bc,&50
  add hl,bc
  inc hl
  inc hl
  inc hl
  jp drawsprite
;ret

vectorlookuphl:
  push bc
  ;rlca ; DOES NOT WORK OVER TABLE LENGTH > 128
  ld b,0
  ld c,a
  add hl,bc
  add hl,bc
  ld a,(hl)
  inc hl
  ld h,(hl)
  ld l,a
  pop bc
ret

; GRAPHICS FUNCTIONS
; ------------------

scr_next_line_hl:
  ld a,h
  add &08
  ld h,a

  ; CHECK IF WE WENT PAST END OF SCREEN
  sub &c0   ; IF USING &8000 FOR SCREEN MEM
  ret c

  ld bc,&C050
  add hl,bc
ret

; DRAW A LINE THE WIDTH OF THE CARD
; INPUTS
; HL = SCREEN MEMORY LOCATION
; A = LINE COLOUR
; A PRESERVED
DrawHorizLineCard:
  push af
  push hl
  ld (hl),a ; LINE COL
  push hl ; COPY HL TO DE
  pop de 
  inc de
  call ldicard
  pop hl
  call scr_next_line_hl
  pop af
ret

; DRAW A LINE THE WIDTH OF THE CARD
ldicard:
  ldi
  ldi
  ldi
  ldi
  ldi
  ldi
  ldi
  ldi
  ldi
ret

; INPUTS
; HL = SCREEN ADDR
; DE = SPRITE ADDR
drawsprite:
  ld b,16 ; 16 ROWS
  drawspriteloop:
	push bc
    push hl
    ex de,hl
	ldi
	ldi
	ldi
	ldi
	ex de,hl
	pop hl
	call scr_next_line_hl
    pop bc
  djnz drawspriteloop
ret
  
; IMAGES
; ---------------------------------

suitstable:
  defw cardclubimg
  defw carddiamondimg
  defw cardheartimg
  defw cardspadeimg

cardclubimg:
        DB      #C0, #C0, #C0, #C0
        DB      #C0, #C0, #C0, #C0
        DB      #C0, #95, #6A, #C0
        DB      #C0, #2E, #1D, #C0
        DB      #C0, #0C, #0C, #C0
        DB      #C0, #2E, #1D, #C0
        DB      #95, #84, #48, #6A
        DB      #2E, #2E, #1D, #1D
		DB      #0C, #0C, #0C, #0C
        DB      #2E, #2E, #1D, #1D
        DB      #95, #84, #48, #6A
        DB      #C0, #84, #48, #C0
        DB      #C0, #2E, #1D, #C0
        DB      #C0, #C0, #C0, #C0
        DB      #C0, #C0, #C0, #C0
		
carddiamondimg:
	    DB      #C0, #C0, #C0, #C0
        DB      #C0, #C0, #C0, #C0
        DB      #C0, #D4, #E8, #C0
        DB      #C0, #90, #60, #C0
        DB      #C0, #B8, #74, #C0
        DB      #C0, #30, #30, #C0
        DB      #D4, #30, #30, #E8
        DB      #90, #30, #30, #60
        DB      #D4, #30, #30, #E8
        DB      #C0, #30, #30, #C0
        DB      #C0, #B8, #74, #C0
        DB      #C0, #90, #60, #C0
        DB      #C0, #D4, #E8, #C0
        DB      #C0, #C0, #C0, #C0
        DB      #C0, #C0, #C0, #C0
        DB      #C0, #C0, #C0, #C0
		
cardheartimg:
	    DB      #C0, #C0, #C0, #C0
        DB      #C0, #C0, #C0, #C0
        DB      #D4, #E8, #D4, #E8
        DB      #90, #60, #90, #60
        DB      #B8, #74, #B8, #74
        DB      #30, #30, #30, #30
        DB      #B8, #30, #30, #74
        DB      #90, #30, #30, #60
        DB      #90, #30, #30, #60
        DB      #D4, #30, #30, #E8
        DB      #C0, #30, #30, #C0
        DB      #C0, #B8, #74, #C0
        DB      #C0, #90, #60, #C0
        DB      #C0, #D4, #E8, #C0
        DB      #C0, #C0, #C0, #C0
        DB      #C0, #C0, #C0, #C0
		
cardspadeimg:
	    DB      #C0, #C0, #C0, #C0
        DB      #C0, #C0, #C0, #C0
        DB      #C0, #95, #6A, #C0
        DB      #C0, #84, #48, #C0
        DB      #C0, #2E, #1D, #C0
        DB      #C0, #0C, #0C, #C0
        DB      #95, #0C, #0C, #6A
        DB      #84, #0C, #0C, #48
        DB      #2E, #0C, #0C, #1D
		DB      #0C, #0C, #0C, #0C
        DB      #2E, #2E, #1D, #1D
        DB      #95, #84, #48, #6A
        DB      #C0, #84, #48, #C0
        DB      #C0, #2E, #1D, #C0
        DB      #C0, #C0, #C0, #C0
        DB      #C0, #C0, #C0, #C0