;Reg 	Meaning 			Bit Meaning 	Details
;0 	Tone Pitch L - Channel A 	LLLLLLLL 	FINE TUNE   - Lower value = Higher pitch
;1 	Tone Pitch H - Channel A 	----HHHH 	COARSE TUNE - Lower value = Higher pitch
;2 	Tone Pitch L - Channel B 	LLLLLLLL 	FINE TUNE   - Lower value = Higher pitch
;3 	Tone Pitch H - Channel B 	----HHHH 	COARSE TUNE - Lower value = Higher pitch
;4 	Tone Pitch L - Channel C 	LLLLLLLL 	FINE TUNE   - Lower value = Higher pitch
;5 	Tone Pitch H - Channel C 	----HHHH 	COARSE TUNE - Lower value = Higher pitch
;6 	Noise Generator 		---NNNNN 	Higher = Faster noise
;7 	Mixer  				--NNNTTT   	N=Noise T=Tone (Channel --CBACBA 1=mute 0=normal)
;8 	Amplitude - Channel A 		---EVVVV 	E=Envelope (1=Enabled) VVVV=Volume
;9 	Amplitude - Channel B 		---EVVVV 	E=Envelope (1=Enabled) VVVV=Volume
;10 	Amplitude - Channel C	 	---EVVVV 	E=Envelope (1=Enabled) VVVV=Volume
;11 	Envelope L (Volume over time)  	LLLLLLLL 	Lower=Faster Envelope
;12 	Envelope H (Volume over time)  	HHHHHHHH 	Lower=Faster Envelope
;13 	Envelope Selection 		----EEEH 	E=Envelope number E (See PDF) H=Hold

;Hardware Envelope shapes
;x indicates bit with any value (either 1 or 0)

;Bits                            Envelope shape

;3       2       1       0
;-----------------------------------------------------------------
;
;0       0       x       x       \________________________
;
;0       1       x       x       /|_______________________
;
;1       0       0       0       \|\|\|\|\|\|\|\|\|\|\|\|\
;
;1       0       0       1       \________________________
;
;1       0       1       0       \/\/\/\/\/\/\/\/\/\/\/\/\
;                                  _______________________
;1       0       1       1       \|
;
;1       1       0       0       /|/|/|/|/|/|/|/|/|/|/|/|/
;                                 ________________________
;1       1       0       1       /
;
;1       1       1       0       /\/\/\/\/\/\/\/\/\/\/\/\/
;
;1       1       1       1       /|_______________________


;Summary

;Bit 7  } Not used
;Bit 6  }
;Bit 5  }
;Bit 4  }

;Bit 3  Continue        ;} See table for envelope shapes.
;Bit 2  Attack          ;}
;Bit 1  Alternate       ;}
;Bit 0  Hold            ;}


org &4000

ld a,3
ld (soundduration+0),a

;; now setup interrupts.
di
im 1

;; wait vsync (loop passes if VSYNC signal is high = in vsync)
ld b,&f5
wait1:
in a,(c)
rra
jr nc,wait1
;; wait for end of vsync (loop passes when VSYNC signal is low = out of vsync)
wait2:
in a,(c)
rra
jr c,wait2
;; now wait again for start (because we know we found the end, if we wait for VSYNC to be active
;; we know it will be the start)
wait3:
in a,(c)
rra
jr nc,wait3


ld a,&c3	;; Z80 JP instruction
ld hl,sounddurationevent	;; first function to call
ld (&0038),a	;; write JP instruction
ld (&0039),hl	;; write address
ei

start:
ld a,3
ld (soundduration+0),a
;call axesound
ret
;call &bb18
;jp start

soundduration:
  defb 0 ; A
  defb 0 ; B
  defb 0 ; C

sounddurationevent:
  call axesound
  ld hl,soundduration+0
  ld a,(hl)
  or a
  jr z,reloadchannela
  dec a ; SILENCE CHANNEL SOUND
  jr z,silencechannela  
  decchannela:
  ld (hl),a
  ; DECREMENT DURATION
  ei
reti
silencechannela:
  ld a,7           ; SET MIXER
  ld c,%10111111   ; %PPNNNTTT (1=off) --CBACBA PP=PORTS
  call RegWrite
  call decchannela
  ei
reti
reloadchannela:
  ld a,3
  ld (soundduration+0),a
  call axesound
  ei
reti

RegWrite:
  push bc
  ld b,&f4
  ld c,a
  out (c),c	;#f4 Regnum

  ld bc,&F6C0	;Select REG
  out (c),c	

  ld bc,&f600	;Inactive
  out (c),c

  ld bc,&F680	;Write VALUE
  out (c),c	
  pop bc
  ld b,&F4	;#f4 value
  out (c),c

  ld bc,&f600	;; "inactive"
  out (c),c
ret

splashsound:
dingsound:
  ld a,7           ; SET MIXER
  ld c,%10111110   ; %PPNNNTTT (1=off) --CBACBA PP=PORTS
  call RegWrite

  xor a
  ld c,%00111111    ; TONE - LOWER 8 BITS - CHANNEL A
  call RegWrite
  ld a,1
  ld c,%00000000    ; TONE - UPPER 4 BITS
  call RegWrite
  
  ld a,13			;SELECT ENVELOPE ----EEEH
  ld c,%00000010
  call RegWrite
  
  ld a,11			;Envelop LLLLLLLL
  ld c,%01001111
  call RegWrite
  ld a,12			;Envelop HHHHHHHH
  ld c,%00000100
  call RegWrite

  ld a,8            ; VOLUME / ENVELOPE FOR CHANNEL A ---EVVVV
  ld c,%00011111    ; E=1 MEANS ENVELOPE ON
  call RegWrite

ret

jumpsound:
  ld a,7           ; SET MIXER
  ld c,%10111110   ; %PPNNNTTT (1=off) --CBACBA PP=PORTS
  call RegWrite

  ; LOWER VALUE = LOWER PITCH
  xor a
  ld c,%01001111    ; TONE - LOWER 8 BITS - CHANNEL A
  call RegWrite
  ld a,1
  ld c,%00000100    ; TONE - UPPER 4 BITS
  call RegWrite
  
  ; H = HOLD ENVELOPE

  ld a,13			;SELECT ENVELOPE ----CXAH
  ld c,%000000010
  call RegWrite
  
  ; HIGHER VALUE = LONGER FADE

  ld a,11			;Envelop LLLLLLLL
  ld c,%00101111
  call RegWrite
  ld a,12			;Envelop HHHHHHHH
  ld c,%00000100
  call RegWrite


  ld a,8            ; VOLUME / ENVELOPE FOR CHANNEL A ---EVVVV
  ld c,%00011011    ; E=1 MEANS ENVELOPE ON
  call RegWrite

ret

doorknock:
arrowsound:
axesound:
  ld a,7           ; SET MIXER
  ld c,%10000110   ; %PPNNNTTT (1=off) --CBACBA PP=PORTS
  call RegWrite

  ; LOWER VALUE = LOWER PITCH
  xor a
  ld c,%01001111    ; TONE - LOWER 8 BITS - CHANNEL A
  call RegWrite
  ld a,1
  ld c,%00000100    ; TONE - UPPER 4 BITS
  call RegWrite
  
  ; H = HOLD ENVELOPE

  ld a,13			;SELECT ENVELOPE ----CXAH
  ld c,%000001010
  call RegWrite
  
  ; HIGHER VALUE = LONGER FADE

  ld a,11			;Envelop LLLLLLLL
  ld c,%00101111
  call RegWrite
  ld a,12			;Envelop HHHHHHHH
  ld c,%00000100
  call RegWrite


  ld a,8            ; VOLUME / ENVELOPE FOR CHANNEL A ---EVVVV
  ld c,%00011111    ; E=1 MEANS ENVELOPE ON
  call RegWrite

ret